#!/usr/bin/env perl
#
# Convert GeoJSON files of Tereno field data in averaged measures and CSV
# format.
#

use v5.18;

use strict;

use warnings; 

use JSON;
use File::Slurp;
use Statistics::Basic qw/:all/;
use Number::Format;

my $us = new Number::Format(-thousands_sep   => ',', -decimal_point   => '.');

say qq/Date|Sensor|Moisture %(mean)|Moisture %(median)|Temp Deg C(mean)|Temp Deg C(median)/;
for my $opt (@ARGV) {
	my @files = glob $opt;
	for my $file (@files) {
		$file =~ m/(\w+)_(\d+)_.+/;
		my $sensor = $1; 
		my $date = $2; 
		my ($y,$m,$d) = unpack "A4A2A2", $date; 
		$date = sprintf "%04d-%02d-%02d", $y, $m, $d;
		my $json = read_file($file);
		my $obj = from_json( $json );
		my @feature = $obj->{features};
		my @moist = ();
		my @temp = ();
		for my $f (@feature) {
			for my $a (@$f) {
				push @moist, $a->{properties}->{'Moisture(%)'};
				push @temp, $a->{properties}->{"Temp_\x{c2}\x{b0}C"};
			}
		}
		my $mean_moist = $us->format_number(mean(@moist));
		my $median_moist = $us->format_number(median(@moist));
		my $mean_temp = $us->format_number(mean(@temp));
		my $median_temp = $us->format_number(median(@temp));
		say qq/$date|\L$sensor\E|$mean_moist|$median_moist|$mean_temp|$median_temp/;
	}
}

