#!/bin/sh
#
# This script extracts SMAP grids on the basis of a subset of cats with some
# statistics as in the following example:
#
#;<x>;<y>;bias;R;rmse;ubrmse;N
#
#cat              <x>       <y>      bias         R      rmse    ubrmse         N	pvalue
#62           0.15585   0.27455   0.11870   0.63708   0.12665   0.04418        30   0.00008
#63           0.16851   0.27761   0.10910   0.67367   0.11860   0.04652        36   0.00000
#64           0.16261   0.24460   0.08199   0.63218   0.10090   0.05880        34   0.00003
#65           0.14923   0.23619   0.08695   0.64606   0.10738   0.06300        32   0.00003
#71           0.16669   0.24521   0.07852   0.61656   0.08707   0.03763        12   0.01637
#72           0.16457   0.25186   0.08729   0.60017   0.09314   0.03249        15   0.00900
#73           0.18351   0.27574   0.09223   0.65210   0.09830   0.03402        32   0.00003

if [ $# -lt 6 ]
then
	echo "usage: $0 report subset track resolution percentage percentage_pv"
	exit 1
fi

REPORT=$1
SUBSET=$2
TRACK=$3
RES=$4
PERC=$5
PERC_PV=$6

if [ ! -f $REPORT ] 
then
	echo "Missing file: $REPORT"
	exit 2
fi
if [ ! -f $SUBSET ] 
then
	echo "Missing file: $SUBSET"
	exit 2
fi

case $RES in
	1|3|9|36)
		RES=${RES}km
		;;
	12d5|12.5)
		RES=12d5km
		;;
    25)
        RES=25km
        ;;
	*)
		echo "Wrong resolution: $RES"
		exit 4
		;;
esac

TMP=$(mktemp -q)

$G_EASE2 g.copy vect=smap_grid_${RES}_Medi_${TRACK},smap${RES}_medi_${TRACK}_work --o
awk -F\| "{if (\$5>=$PERC && \$9!=0 && \$10==\$1) print \$2}" $REPORT|tail -n +2|sort -n|uniq >$TMP
$G_EASE2 v.extract in=smap${RES}_medi_${TRACK}_work file=$TMP out=result --o
$G_EASE2 v.db.addcolumn map=result col='x_mean double precision, y_mean double precision, bias double precision, r double precision, rmse double precision, ubrmse double precision, n integer, pv double precision'
for l in $(grep -v NaN $SUBSET|tail -n +2|awk -F' ' "{if (\$9<=$PERC_PV) print \$1,\$2,\$3,\$4,\$5,\$6,\$7,\$8,\$9}"|sed -e 's/ /|/g')
do 
	cat=$(echo $l|awk -F\| '{print $1}')
	x=$(echo $l|awk -F\| '{print $2}')
	y=$(echo $l|awk -F\| '{print $3}')
	b=$(echo $l|awk -F\| '{print $4}')
	r=$(echo $l|awk -F\| '{print $5}')
	rmse=$(echo $l|awk -F\| '{print $6}')
	ubrmse=$(echo $l|awk -F\| '{print $7}')
	n=$(echo $l|awk -F\| '{print $8}')
	pv=$(echo $l|awk -F\| '{print $9}')
	$G_EASE2 v.db.update map=result col=x_mean value=$x where="cat=$cat"
	$G_EASE2 v.db.update map=result col=y_mean value=$y where="cat=$cat"
	$G_EASE2 v.db.update map=result col=bias value=$b where="cat=$cat"
	$G_EASE2 v.db.update map=result col=r value=$r where="cat=$cat"
	$G_EASE2 v.db.update map=result col=rmse value=$rmse where="cat=$cat"
	$G_EASE2 v.db.update map=result col=ubrmse value=$ubrmse where="cat=$cat"
	$G_EASE2 v.db.update map=result col=n value=$n where="cat=$cat"
	$G_EASE2 v.db.update map=result col=pv value=$pv where="cat=$cat"
done

$G_EASE2 v.db.update map=result col=x_mean value=0 where="x_mean is NULL";
$G_EASE2 v.db.update map=result col=y_mean value=0 where="y_mean is NULL";
$G_EASE2 v.db.update map=result col=bias value=0 where="bias is NULL";
$G_EASE2 v.db.update map=result col=r value=0 where="r is NULL";
$G_EASE2 v.db.update map=result col=rmse value=0 where="rmse is NULL";
$G_EASE2 v.db.update map=result col=ubrmse value=0 where="ubrmse is NULL";
$G_EASE2 v.db.update map=result col=n value=0 where="n is NULL";
$G_EASE2 v.db.update map=result col=pv value=0 where="pv is NULL";
$G_EASE2 v.out.ogr in=result out=$SM_TOOLS_OUTPUTDIR/smap_grid_${RES}_Medi_${TRACK}_sieved_$$.shp  --o

exit 0

