#!/bin/sh
#
# This script read an ASCAT stats file in percentage and add information about the 
# volumetric sm contents. 
#

if [ $# -lt 2 ]
then
	cat <<EOF
usage: $0 <file> <Medi tag>
ex. $0 Medi_D110_ascat_grid_12d5km_Medi_D110_report.txt D110
EOF
	exit 1
fi

FILE=$1
DIR=$(dirname $FILE)
TAG=Medi_$2
RES=12d5

directory=/net/milos/ocean/data/ESA-SEOM/ascat_volsm
pre=
post=_am_ascat.tif

reference=smap_grid_${RES}km_${TAG}

set -e

head=$(head -1 $FILE)
echo "$head|volumetric sm" >$DIR/$(basename $FILE .txt)_volumetric.txt
for line in $(tail -n +2 $FILE)
do
	cat=$(echo $line|cut -d\| -f2)
	date=$(echo $line|cut -d\| -f10)
	isodate=$(echo $date|sed -e 's/-//g')
	file=$(ls $directory/${pre}${isodate}${post} 2>/dev/null || true)
	if [ -f "$file" ]
	then
		$G_EASE2 g.remove t=rast name=map -f
		$G_EASE2 r.external in=$file out=map
		$G_EASE2 g.region rast=map
		res=$($G_EASE2 v.out.ascii --q type=centroid in=$reference where="cat=$cat")
		x=$(echo $res|cut -d\| -f1)
		y=$(echo $res|cut -d\| -f2)
		val=$($G_EASE2 r.what null=0 map=map coordinates=$x,$y|cut -d\| -f4)
		echo "$line|$val" >>$DIR/$(basename $FILE .txt)_volumetric.txt
	else
		echo "$line|unmatched" >>$DIR/$(basename $FILE .txt)_volumetric.txt
	fi
done
