#!/bin/sh
#
# This script read a SMAP/SMOS/ASCAT stats file and add information about the 
# filtered-by-flag version of the image. The filtered version is created by
# smapsmosascat_filter_by_flag.sh script.
#

if [ $# -lt 3 ]
then
	ca <<EOF
usage: $0 <file> <Medi tag> <12.5|25|36>
ex. $0 Medi_D110_smap_grid_25km_Medi_D110_report.txt D110 25
EOF
	exit 1
fi

FILE=$1
DIR=$(dirname $FILE)
TAG=Medi_$2
RES=$3

case $RES in
	36)
		directory=/net/milos/ocean/data/ESA-SEOM/filtered/SMAP36km
		pre=SMAP_L3_SM_P_
		post=_*_am.tif
		;;
	25)
		directory=/net/milos/ocean/data/ESA-SEOM/filtered/SMOS25km
		pre=SM_OPER_MIR_CLF31A_
		post=*_sm.tif
		;;
	12.5)
		directory=/net/milos/ocean/data/ESA-SEOM/filtered/ASCAT12.5km
		pre=
		post=_am_sm.tif
		RES=12d5
		;;
	*)
		echo "$0: wrong resolution used for filtered images"
		exit 2
		;;
esac

reference=smap_grid_${RES}km_${TAG}

set -e

head=$(head -1 $FILE)
echo "$head|filtered" >$DIR/$(basename $FILE .txt)_filtered.txt
for line in $(tail -n +2 $FILE)
do
	cat=$(echo $line|cut -d\| -f2)
	date=$(echo $line|cut -d\| -f10)
	isodate=$(echo $date|sed -e 's/-//g')
	file=$(ls $directory/${pre}${isodate}${post} 2>/dev/null || true)
	if [ -f "$file" ]
	then
		$G_EASE2 g.remove t=rast name=smap -f
		$G_EASE2 r.external in=$file out=smap
		$G_EASE2 g.region rast=smap
		res=$($G_EASE2 v.out.ascii --q type=centroid in=$reference where="cat=$cat")
		x=$(echo $res|cut -d\| -f1)
		y=$(echo $res|cut -d\| -f2)
		val=$($G_EASE2 r.what null=0 map=smap coordinates=$x,$y|cut -d\| -f4)
		echo "$line|$val" >>$DIR/$(basename $FILE .txt)_filtered.txt
	else
		echo "$line|unmatched" >>$DIR/$(basename $FILE .txt)_filtered.txt
	fi
done
