#!/bin/sh
#
# Extract globcover/texture rasters, this version works with gdal 2.4+
#

set -e

if [ $# -ne 3 ]
then
	echo usage: $0 reference_file landcover_dir texture_dir
fi

if [ -z "$(which pkinfo)" ]; then
	echo "Missing pktools"
	exit 1
fi

#gcover=$SM_TOOLS_LANDCOVER/GLOBCOVER_L4_200901_200912_V2.3.tif
gcover=$SM_TOOLS_LANDCOVER/ESACCI-LC-L4-LCCS-Map-300m-P1Y-2015-v2.0.7.tif
texturedir=$SM_TOOLS_TEXTURE
RES=$(pkinfo -i $1 -dx -dy|cut -d\  -f2,4)
EXT=$(pkinfo -i $1 -te|cut -d\  -f2-)

gdalwarp -overwrite -of "ENVI" -te $EXT -tr $RES $gcover $2/CCI_LCOVER_image.img

gdalwarp -overwrite  -of ENVI -tr $(pkinfo -i $texturedir/CLYPPT_M_sl1_250m.tif -dx -dy|cut -d\  -f2,4) -te $EXT $texturedir/CLYPPT_M_sl1_250m.tif $3/clay_250m
gdalwarp -overwrite  -of ENVI -tr $(pkinfo -i $texturedir/SNDPPT_M_sl1_250m.tif -dx -dy|cut -d\  -f2,4) -te $EXT $texturedir/SNDPPT_M_sl1_250m.tif $3/sand_250m
gdalwarp -overwrite  -of ENVI -tr $(pkinfo -i $texturedir/SLTPPT_M_sl1_250m.tif -dx -dy|cut -d\  -f2,4) -te $EXT $texturedir/SLTPPT_M_sl1_250m.tif $3/silt_250m
clay_mean=$(gdalinfo -stats $3/clay_250m|grep MEAN|cut -d= -f2)
sand_mean=$(gdalinfo -stats $3/sand_250m|grep MEAN|cut -d= -f2)
silt_mean=$(gdalinfo -stats $3/silt_250m|grep MEAN|cut -d= -f2)
gdalwarp -overwrite -dstnodata $clay_mean $texturedir/CLYPPT_M_sl1_250m.tif $tmpdir/clay.tif
gdalwarp -overwrite -dstnodata $sand_mean $texturedir/SNDPPT_M_sl1_250m.tif $tmpdir/sand.tif
gdalwarp -overwrite -dstnodata $silt_mean $texturedir/SLTPPT_M_sl1_250m.tif $tmpdir/silt.tif
gdalwarp -overwrite -srcnodata None -r bilinear -of ENVI -tr $RES -te $EXT $tmpdir/clay.tif  $3/isric_soil_texture_clay
gdalwarp -overwrite -srcnodata None -r bilinear -of ENVI -tr $RES -te $EXT $tmpdir/sand.tif  $3/isric_soil_texture_sand
gdalwarp -overwrite -srcnodata None -r bilinear -of ENVI -tr $RES -te $EXT $tmpdir/silt.tif  $3/isric_soil_texture_silt

