#!/bin/bash 
#
# Create DEM mosaics starting from a list of files of images.
# This is a GRASS script! Note that the original SRTM tiles as available from USGS have to be available 
# in the SRTM mapset. This is not checked in advance. The script works only with the 3arcsec tiles and
# and it should be refined to select a limited subset of tiles before mosaicing all them together.
#

if [ $# -lt 2 ]
then
	echo "usage: $0 dem_output frame ..."
	exit 1
fi

output=$1
shift
frames="$@"

if [ -z $(2>/dev/null $G which r.in.srtm.region) ]
then
	echo "Missing extension 'r.in.srtm.region', please install it using g.extension in a GRASS session"
	exit 2
fi

if [ ! -r $SM_USGS_EE_ENV ]
then
	echo "Missing or not readable required credentials for USGS/USGS EarthExplorer in $SM_USGS_EE_ENV"
	exit 4
fi
eval $(cat $SM_USGS_EE_ENV)

set -e

declare -a P

TEMPDIR=$(mktemp -dq)

for i in $frames
do
	echo $i
	# use basename and strip last extension if present, which could be .SAFE or .zip
	b=$(echo $i|perl -p -e 's{\.[^.]+$}{}; s{.*/}{}')
	#fp=$(spatialite $SM_TOOLS_DB "select ST_AsText(footprint) from Image where provider_filename='$b'")
	fp=$(ogrinfo -al $i/preview/map-overlay.kml|grep POLYGON)
	if [ -z "$fp" ]
	then
		echo "Missing frame footprint for $b"
		exit 3
	fi
	P[b]="$fp"
	# Create vector geometries starting from WKTs
	np=$(echo ${P[b]}|sed -e 's/POLYGON/ /' -e 's/((//' -e 's/))//' -e 's/,/\n/g'|wc -l)
	cat >$TEMPDIR/$$.txt <<EOF && echo ${P[b]}|sed -e 's/POLYGON/ /' -e 's/((//' -e 's/))//' -e 's/,/\n/g' >>$TEMPDIR/$$.txt
B $np
EOF
	$G v.in.ascii -n --o input=$TEMPDIR/$$.txt output="G$$__$b" format=standard --q
done

list=$($G g.list pat="G$$__*" sep=, t=vect)
$G g.region vect=$list

# Enlarge the region of 0.5deg in each direction and maintain the original
#u resolution of 3 arcsec.
$G g.region -a n=n+0:30:0 s=s-0:30:0 w=w-0:30:0 e=e+0:30:0 res=00:00:03

out=$(basename $output .img)

source $SM_USGS_EE_ENV

$G r.in.srtm.region user=$SM_USGS_USER password=$SM_USGS_PASSWD output=${out} memory=10000 url="https://e4ftl01.cr.usgs.gov/MEASURES/SRTMGL3.003/2000.02.11/" --v
$G r.out.gdal input=${out} output=${output} format="ENVI" type=Int16 --o

$G g.remove name=${out} t=rast -f || true
list=$($G g.list pat="G$$__*" sep=, t=vect)
$G g.remove name=$list t=vect -f || true

rm -rf $TEMPDIR

$G_CLEAN

exit 0
