#!/bin/bash
#
# This script has been used to extract site centroids at SMAP resolution with 
# selection of corresponding SMAP grid cell to extract SMAP values.
# Here we are using a pre-built 36km global grid already available for SMAP as
# a polygonal vector file.
#

$SM_TOOLS/etc/grass_check.sh || exit 1

g=$G_EASE2_PERM

$g v.in.ogr in=SMAP_EASE2_36km_Global.shp out=SMAP_EASE2_36km_Global snap=1e-08 --o
$g v.proj in=sites_centroids location=WGS84 out=sites_centroids 
$g v.select ainput=SMAP_EASE2_36km_Global binput=sites_centroids atype=area btype=point output=sites_grids oper=intersects 

#
# FIXME
# Here it needs to join tables taken from EASE2 grid and
# site_centroids but it is still a missing part, it is done by hand by adding
# a 'site' field with the correct name, as found interactively.
# This could be avoided by using v.distance, see the SMOS case for its use.
#
$g v.db.addcol map=sites_grids col="site varchar(50)"
$g v.db.update map=sites_grids col=site value='segezia' where='cat=325392'
$g v.db.update map=sites_grids col=site value='elmcreek' where='cat=345332'
$g v.db.update map=sites_grids col=site value='littlewashita' where='cat=307736'
$g v.db.update map=sites_grids col=site value='txson' where='cat=294238'
$g v.db.update map=sites_grids col=site value='remedhus' where='cat=325336'
$g v.db.update map=sites_grids col=site value='hobe' where='cat=358151'
$g v.db.update map=sites_grids col=site value='yanco' where='cat=83778'

# export resulting sites_grids 
$g v.out.ogr in=sites_grids in=sites_grids type=area --o

# create separate vectors for each site with corresponding SMAP grid polygon
sites=$($g v.db.select -c sites_grids col=site)
for s in $sites; do $g v.extract type=area in=sites_grids out=${s}_smap_grid where="site='$s'" --o; done

# Note that now you should to reproject in WGS84 the resulting vector and do
# the same splitting by geometry there, to be consistent.

