#!/bin/bash
#
# This script has been used to extract site centroids at SMOS resolution with 
# selection of corresponding SMOS grid cell to extract SMAP values.
#
# In this case we are using an available vector file of 25km cell centroids
# extended to the whole globe. See https://nsidc.org/data/ease/tools in the
# section Geolocation Data Files for the lon/lat coordinates. 
#
# The same approach could be used for the SMAP case with 36km of resolution,
# but we used the original polygonal shapefile provided for the same purpose.
#

$SM_TOOLS/etc/grass_check.sh || exit 1

g=$G_EASE2_PERM

# Site centroids and SMOS centroids should already be ready in the WGS84
# location for use. That can be done as follows:
# 
# ease_coords2csv <long_file> <lat_file> >/tmp/ease25km.txt
# v.in.ascii input=/tmp/ease25km.txt output=ease2_25km_centroids
# v.in.ogr in=sites_centroids.shp sites_centroids

$g v.proj in=sites_centroids location=WGS84 out=sites_centroids
$g v.proj location=WGS84 mapset=PERMANENT in=ease2_25km_centroids out=ease2_25km_centroids --o

# resolution is taken from the Gamma images to avoid inconsistencies...
$g g.region vect=ease2_25km_centroids -a rows=584 cols=1388 res=25025.2600081 -a
$g v.mkgrid grid=584,1388 pos=region map=SMAP_EASE2_25km_Global --o

$g v.select ainput=SMAP_EASE2_25km_Global atype=area binput=sites_centroids btype=point output=sites_grids_25km op=intersects
$g v.db.addcol map=sites_grids_25km col='site varchar(50)'
$g v.distance -p from=sites_centroids to=sites_grids_25km to_type=area upload=cat col=cat 

for line in $($g v.distance -p from=sites_centroids to=sites_grids_25km to_type=area upload=cat col=cat|tail -n +2) 
do 
	cat1=$(echo $line|cut -d\| -f1); 
	cat2=$(echo $line|cut -d\| -f2); 
	site=$($g v.report map=sites_centroids opt=coor|grep ^$cat1|cut -d\| -f2); 
	$g v.db.update map=sites_grids_25km val=$site col=site where="cat=$cat2"; 
done
sites=$($g v.db.select sites_grids_25km|cut -d\| -f4)
for s in $sites
do 
	$g v.extract type=area in=sites_grids_25km out=${s}_smos_grid where="site='$s'" --o; 
done
