#!/bin/sh
#
# This script finds the land cover and texture classes covered on
# specific areas.
#

set -e

if [ $# -lt 1 ]
then
	echo "usage: $0 aoi_shapefile"
	exit 1
fi

TARGET=$1.shp

CLAY=$SM_TOOLS_TEXTURE/CLYPPT_M_sl1_250m.tif
SAND=$SM_TOOLS_TEXTURE/SNDPPT_M_sl1_250m.tif
LC=$SM_TOOLS_LANDCOVER/ESACCI-LC-L4-LCCS-Map-300m-P1Y-2015-v2.0.7.tif

$G v.import in=$TARGET out=target --o
gdalwarp -overwrite  -wo 'CUTLINE_ALL_TOUCHED=TRUE' -of ENVI -cutline $TARGET -crop_to_cutline $SAND $SM_TOOLS_TMPDIR/sand
gdalwarp -overwrite  -wo 'CUTLINE_ALL_TOUCHED=TRUE' -of ENVI -cutline $TARGET -crop_to_cutline $CLAY $SM_TOOLS_TMPDIR/clay
gdalwarp -overwrite  -wo 'CUTLINE_ALL_TOUCHED=TRUE' -of ENVI -cutline $TARGET -crop_to_cutline $LC $SM_TOOLS_TMPDIR/lc

$G r.external in=$SM_TOOLS_TMPDIR/sand out=SAND --o
$G r.external in=$SM_TOOLS_TMPDIR/clay out=CLAY --o
$G r.external in=$SM_TOOLS_TMPDIR/lc out=LC --o

$G g.region rast=SAND
$G g.region vect=target 
$G r.soils.texture sand=SAND clay=CLAY out=texture scheme=$SM_TOOLS/etc/USDA.dat --o
$G r.null setnull=0 map=texture 
perl -E "say '+'x79"
echo $1 TEXTURE
perl -E "say '+'x79"
$G r.report map=texture unit=c

$G g.region rast=LC
$G g.region vect=target 
$G r.category rules=- map=LC sep=: <<EOF
0:No Data
10:Cropland, rainfed
11:Herbaceous cover
12:Tree or shrub cover
20:Cropland, irrigated or post‐flooding
30:Mosaic cropland (>50%) / natural vegetation (tree, shrub, herbaceous cover) (<50%)
40:Mosaic natural vegetation (tree, shrub, herbaceous cover) (>50%) / cropland (<50%)
50:Tree cover, broadleaved, evergreen, closed to open (>15%)
60:Tree cover, broadleaved, deciduous, closed to open (>15%)
61:Tree cover, broadleaved, deciduous, closed (>40%)
62:Tree cover, broadleaved, deciduous, open (15‐40%)
70:Tree cover, needleleaved, evergreen, closed to open (>15%)
71:Tree cover, needleleaved, evergreen, closed (>40%)
72:Tree cover, needleleaved, evergreen, open (15‐40%)
80:Tree cover, needleleaved, deciduous, closed to open (>15%)
81:Tree cover, needleleaved, deciduous, closed (>40%)
82:Tree cover, needleleaved, deciduous, open (15‐40%)
90:Tree cover, mixed leaf type (broadleaved and needleleaved)
100:Mosaic tree and shrub (>50%) / herbaceous cover (<50%)
110:Mosaic herbaceous cover (>50%) / tree and shrub (<50%)
120:Shrubland
121:Evergreen shrubland
122:Deciduous shrubland
130:Grassland
140:Lichens and mosses
150:Sparse vegetation (tree, shrub, herbaceous cover) (<15%)
151:Sparse tree (<15%)
152:Sparse shrub (<15%)
153:Sparse herbaceous cover (<15%)
160:Tree cover, flooded, fresh or brakish water
170:Tree cover, flooded, saline water
180:Shrub or herbaceous cover, flooded, fresh/saline/brakish water
190:Urban areas
200:Bare areas
201:Consolidated bare areas
202:Unconsolidated bare areas
210:Water bodies
220:Permanent snow and ice
EOF
perl -E "say '+'x79"
echo $1 LAND COVER
perl -E "say '+'x79"
$G r.report map=LC unit=c

exit 0
