#!/bin/sh
#
# Extract averages of in-field data for all sites, on a daily basis
# and averaged for all stations.
#

set -e

cd $SM_TOOLS_OUTPUTDIR

if [ $# -eq 1 ]
then
	name=$(printf "%s" "$1")
	site=$(spatialite -noheader $SM_TOOLS_DB "select n.id, s.name from Network as n, Site as s where n.site_id=s.id and s.name='$name' order by n.id asc")
else
	site=$(spatialite -noheader $SM_TOOLS_DB "select n.id, s.name from Network as n, Site as s where n.site_id=s.id order by n.id asc")
fi

for s in $(echo $site)
do
	net_id=$(echo $s|cut -d\| -f1)
	site_name=$(echo $s|cut -d\| -f2)
	echo $site_name
	echo "Date|Hour|Depth|Average|Sample StdDev|Count" >${site_name}_stats_by_site_hourly.txt
		spatialite -noheader $SM_TOOLS_DB "
		select date(m.datetime) as d, strftime('%H',m.datetime) as o, m.depth_max as h, avg(m.value*s.a+s.b) as v, stddev_samp(m.value*s.a+s.b) as t, count(m.value) as c 
			from Measure as m, Sensor as s  
			where m.depth_max<=0.05 and m.value*s.a+s.b>0 and
			s.id=m.sensor_id and m.type='soil_moisture' and m.sensor_id in 
			(select id from Sensor where network_id=$net_id) 
			group by 1, 2, 3 order by 1, 2, 3
	" >>${site_name}_stats_by_site_hourly.txt
done

exit 0
