#!/bin/sh

set -e

if [ -z "$GRASS_VERSION" ]
then
	echo "Run this program under GRASS, please"
	echo <<EOF
Suggested setup:
GISDBASE=$HOME/grass/geodb
LOCATION_NAME=UTM33N
MAPSET=SM_TOOLS
EOF
	exit 1
fi

if [ $# -lt 2 ]
then
	echo "Missing arguments: $0 file1 file2"
fi

# while IFS='' read -r line; do ~/sm-tools/misc/grass_S2_Foggia.sh $line; done<lista 

S1=$1
S2=$2

D1=$(dirname $S1)
F1=$(basename $S1 .jp2|cut -d_ -f1,2 --output-delimiter=_)
D2=$(dirname $S2)
F2=$(basename $S2 .jp2|cut -d_ -f1,2 --output-delimiter=_)

r.in.gdal in=${D1}/${F1}_B04.jp2 out=${F1}.R --o
exit
r.in.gdal in=${D1}/${F1}_B03.jp2 out=${F1}.G --o
r.in.gdal in=${D1}/${F1}_B02.jp2 out=${F1}.B --o
r.in.gdal in=${D1}/${F1}_B08.jp2 out=${F1}.N --o

r.in.gdal in=${D2}/${F2}_B04.jp2 out=${F2}.R --o
r.in.gdal in=${D2}/${F2}_B03.jp2 out=${F2}.G --o
r.in.gdal in=${D2}/${F2}_B02.jp2 out=${F2}.B --o
r.in.gdal in=${D2}/${F2}_B08.jp2 out=${F2}.N --o

g.region vect=sensagri_cra_aoi_fg -a res=10

i.group group=${F1} in=${F1}.R,${F1}.G,${F1}.B,${F1}.N --o
i.group group=${F2} in=${F2}.R,${F2}.G,${F2}.B,${F2}.N --o

M=mosaic_${F1}-${F2}
for b in R G B N
do
	r.patch in=${F1}.$b,${F2}.$b out=${M}.$b
done
i.group group=${M} in=${M}.R,${M}.G,${M}.B,${M}.N --o

r.out.gdal -c -f in=${M} out=${M}_RGBN.tif type=UInt16 

g.remove t=group name=${M},${F1},${F2} -f
g.remove t=rast name=${F1}.R,${F1}.G,${F1}.B,${F1}.N,${F2}.R,${F2}.G,${F2}.B,${F2}.N,${M}.R,${M}.G,${M}.B,${M}.N -f
