#!/bin/sh

if [ $# -lt 3 ]
then
	echo "Usage: $0 <image> <track_label> <outprefix> [ resolution ... ]"
	exit 2
fi

L=$1
TRACK=$2
O=$3

if [ $# -lt 4 ]
then
	RESOLUTIONS="36 25 12d5 9 3 1"
else
	shift 3
	RESOLUTIONS=$*
fi

if [ $($G g.list pat="smap_grid_*km_${TRACK}" t=vect|wc -l) -eq 0 ]
then
	echo "SMAP grid at required resolutions not found"
	exit 3
fi

set -e

# statistics are simplified by pre-rasterizing for bigger resolutions
# it needs a weighted by area approach when raster and grid are almost
# of the same order, i.e. very few pixels are involved.
REPORT_1=$(mktemp -q)
REPORT_2=$(mktemp -q)

for RES in $RESOLUTIONS
do
	V="smap_grid_${RES}km_${TRACK}"
	echo "cat|count|tot|perc|mean|stddev" >${O}_${V}_report.txt
done

for line in $L
do
	R=$(echo $line)
	B=$(basename $R .inc)
	$G r.external in=$R out=$B --o
	# Filtering out incidence angles >= 1.57 eventually present
	$G g.region rast=${B}
	$G r.mapcalc "${B}_filt=if($B-1.57,null(),null(),$B)" --o
	for RES in $RESOLUTIONS
	do
		V="smap_grid_${RES}km_${TRACK}"
		R_RES=$(pkinfo -dx -dy -i $R|cut -d' ' -f4,2 --output-delimiter=,)
		EW_RES=$(echo $R_RES|cut -d, -f1)
		NS_RES=$(echo $R_RES|cut -d, -f2)
		$G g.region -a rast=${B}_filt ewres=$EW_RES nsres=$NS_RES
		$G r.mask -r || true
		$G v.to.rast in=$V use=cat out=$V --o
		$G i.segment.stats -c map=$V rasters=$V raster_statistics= area_measures=area csvfile=$REPORT_1 --o
		$G r.mask raster=${B}_filt --o
		$G i.segment.stats -c map=$V rasters=${B}_filt raster_statistics=mean,stddev area_measures=area csvfile=$REPORT_2 --o
		tail -n +2 $REPORT_1 | sort -n -t \| -k 1 >${O}_${V}_report1.txt
		tail -n +2 $REPORT_2 | sort -n -t \| -k 1 >${O}_${V}_report2.txt
		for l in $(cat ${O}_${V}_report2.txt)
		do
			k=$(echo $l|cut -d\| -f1)
			a=$(egrep "^$k\|" ${O}_${V}_report1.txt|cut -d\| -f2)
			echo "$l|$a" |awk -F\| \
				'{printf("%d|%d|%d|%d|%f|%f\n",$1,$2,$5,100*($2/$5),$3,$4)}' >>${O}_${V}_report.txt
		done
		rm -f ${O}_${V}_report?.txt
	done
	rm -f $REPORT_1 $REPORT_2 
done

$G_CLEAN

exit 0
