#!/bin/sh

set -e

if [ $# -lt 2 ] 
then
	echo "usage: $0 <tag> sm|s0"
	exit 1
fi

TAG=$1
TYPE=$2
TEMP_FILE=$(mktemp -q)

case "$TYPE" in
	sm)
		sql="select filename,date(reference_datetime),product_type from Product where tag='$TAG'"
		spatialite $SM_TOOLS_DB "$sql"|sed -e 's/ /_/g' >$TEMP_FILE
		;;
	s0)
		sql="select filename,date(reference_datetime),product_type from ProcessedImage where tag='$TAG'"
		spatialite $SM_TOOLS_DB "$sql"|sed -e 's/ /_/g' >$TEMP_FILE
		;;
	*)
		echo "usage: $0 <tag> sm|s0"
		exit 2
		;;
esac

# FIXME: this snippet works only for specific tagging conventions :-/
case $TAG in
	*medi.d*|*medi.a*)
		TARGET=Medi_$(echo $TAG|perl -pe 's/.*medi[_.]([da]\d+).*/medi.$1/'|cut -d. -f2|cut -d_ -f1|tr a-z A-Z)
		;;
	*medi_d*|*medi_a*)
		TARGET=Medi_$(echo $TAG|perl -pe 's/.*medi[_.]([da]\d+).*/medi_$1/'|sed -e 's/medi_/medi./'|cut -d. -f2|cut -d_ -f1|tr a-z A-Z)
		;;
	*remedhus_d*|*remedhus_a*)
		TARGET=Remedhus_$(echo $TAG|perl -pe 's/.*medi[_.]([da]\d+).*/medi_$1/'|sed -e 's/medi_/medi./'|cut -d. -f2|cut -d_ -f1|tr a-z A-Z)
		;;
	*)
		echo "$0: malformed tag"
		exit 3
		;;
esac

for m in $TEMP_FILE
do
	if [ $(ls $SM_TOOLS_OUTPUTDIR/smap_grids_sampling/SMAP*_$TARGET.txt|wc -l) -eq 0 ]
	then
			$SM_TOOLS/misc/smapsmosascat_grid_sampling.sh 36 $(echo $TARGET|sed -e 's/Medi_//')
			$SM_TOOLS/misc/smapsmosascat_grid_sampling.sh 25  $(echo $TARGET|sed -e 's/Medi_//')
			$SM_TOOLS/misc/smapsmosascat_grid_sampling.sh 12d5 $(echo $TARGET|sed -e 's/Medi_//')
			$SM_TOOLS/misc/smapsmosascat_grid_sampling.sh 9 $(echo $TARGET|sed -e 's/Medi_//')
			$SM_TOOLS/misc/smapsmosascat_grid_sampling.sh 3 $(echo $TARGET|sed -e 's/Medi_//')
			$SM_TOOLS/misc/smapsmosascat_grid_sampling.sh 1 $(echo $TARGET|sed -e 's/Medi_//')
			$SM_TOOLS/misc/smapsmosascat_grid_sampling.sh 1D $(echo $TARGET|sed -e 's/Remedhus_//')
	fi
	mkdir -p $SM_TOOLS_OUTPUTDIR/${TAG} 2>/dev/null || true
	$SM_TOOLS/misc/make_ease2_stats_bytag.sh $m $TARGET $SM_TOOLS_OUTPUTDIR/${TAG}/${TARGET}; 
done
