#!/bin/sh
#
# This script creates RGN multi-band images extracted from S2 images.
#
OUTDIR=$1
shift 1
if [ $# -lt 1 ]
then
	echo "usage: $0 outputdir s2_image.zip ..."
	exit 1
fi
FRAMES="$@"

TEMPDIR=$(mktemp -dq)

mkdir -p $OUTDIR || true

set -e

for F in $FRAMES
do
	B=$(basename $F .zip)
	D=$(dirname $F)
	mkdir "$TEMPDIR/$B"
	unzip -j -o -d "$TEMPDIR/$B" "$D/$B" "*B04_10m.jp2" "*B08_10m.jp2" "*B03_10m.jp2"
	B4=$(basename $TEMPDIR/$B/*B04_10m.jp2 .jp2)
	B8=$(basename $TEMPDIR/$B/*B08_10m.jp2 .jp2)
	B3=$(basename $TEMPDIR/$B/*B03_10m.jp2 .jp2)
	gdalwarp -overwrite -t_srs EPSG:4326 -of ENVI $TEMPDIR/$B/$B4.jp2 $OUTDIR/$B4
	gdalwarp -overwrite -t_srs EPSG:4326 -of ENVI $TEMPDIR/$B/$B8.jp2 $OUTDIR/$B8
	gdalwarp -overwrite -t_srs EPSG:4326 -of ENVI $TEMPDIR/$B/$B3.jp2 $OUTDIR/$B3
	gdalbuildvrt -separate $OUTDIR/$B.vrt $OUTDIR/$B8 $OUTDIR/$B4 $OUTDIR/$B3
	rm -rf $TEMPDIR/$B
done

rm -rf $TEMPDIR

exit 0
