#!/bin/sh
#
# This is used to compute NDVI for S2 starting from UTM zone
# under GRASS 7.x+. 
# Note that the group of S2 files used as input argument are mosaicated together 
# against the target frame used as reference. Output name 
#

$SM_TOOLS/etc/grass_check.sh || exit 1

TARGET=$1
OUTPUT=$2
shift 2
if [ $# -lt 1 ]
then
	echo "usage: $0 reference_frame output_file_name s2_image1.zip ..."
	exit 1
fi
FRAMES="$@"

TEMPDIR=$(mktemp -dq)

set -e

$G r.external in=$TARGET out=target --o
for F in $FRAMES
do
	B=$(basename $F .zip)
	D=$(dirname $F)
	mkdir "$TEMPDIR/$B"
	unzip -j -o -d "$TEMPDIR/$B" "$D/$B" "*B04_10m.jp2" "*B08_10m.jp2" "*SCL_20m.jp2"
	B4=$(basename $TEMPDIR/$B/*B04_10m.jp2 .jp2)
	B8=$(basename $TEMPDIR/$B/*B08_10m.jp2 .jp2)
	SCL=$(basename $TEMPDIR/$B/*SCL_20m.jp2 .jp2)
	gdalwarp -overwrite -t_srs EPSG:4326 -of ENVI $TEMPDIR/$B/$B4.jp2 $TEMPDIR/$B4
	gdalwarp -overwrite -t_srs EPSG:4326 -of ENVI $TEMPDIR/$B/$B8.jp2 $TEMPDIR/$B8
	gdalwarp -overwrite -t_srs EPSG:4326 -of ENVI $TEMPDIR/$B/$SCL.jp2 $TEMPDIR/$SCL
	$G r.external in=$TEMPDIR/$B4 out=$B4 --o
	$G r.external in=$TEMPDIR/$B8 out=$B8 --o
	$G r.external in=$TEMPDIR/$SCL out=$SCL --o
	$G g.region -a rast=$B4
	$G r.reclass in=$SCL out=MASK rules=- --o <<EOF
4 5 10 = 1
* = NULL
EOF
	$G r.mapcalc --o <<EOF
${B4}_m=$B4
${B8}_m=$B8
EOF
	$G r.mapcalc --o <<EOF
ndvi_$B=float(${B8}_m-${B4}_m)/float(${B8}_m+${B4}_m)
EOF
	$G g.remove t=rast name=MASK,$B4,$B8,$SCL,${B4}_m,${B8}_m -f
	rm -rf $TEMPDIR/$B
done

# patch all frames together, so list needs to be arranged
# in a sensible way
B=$(basename $F .zip)
$G g.region -a rast=target
if [ $($G g.list t=rast pat='ndvi_*'|wc -l) -ge 2 ]
then
	$G r.patch in=$($G g.list t=rast pat='ndvi_*' sep=,) out=ndvi --o
else
	$G g.copy rast=$($G g.list t=rast pat='ndvi_*'),ndvi --o
fi
$G r.out.gdal in=ndvi format=ENVI type=Float32 out=$OUTPUT --o

rm -rf $TEMPDIR
$G g.remove t=rast name=ndvi,target,$($G g.list t=rast pat='ndvi_*' sep=,) -f

exit 0
