#!/bin/bash
#
# This script extracts statistics on a site by grouping together sensors
# within the same cell of a certain size (1km, 3km, 9km).
# 
# This script can also be called with two optional argument that is the site
# name and the 'tag' of a SM injection.
#
# This script is modeled onto the Segezia version (and simplifies it) which
# used mixed CRSes and a limited number of geometries.
# 

S=yanco
if [ $# -eq 1 ]; then
	S="$1"
fi

cat <<EOF
Site: $S
EOF

set -e

D=$SM_TOOLS_OUTPUTDIR
T=$SM_TOOLS_TMPDIR
R=$SM_TOOLS_REPO
N=$(date +%Y%m%d)

# Prepare WKT geometries 
source $SM_TOOLS/misc/gen_${S}_grid_polys.sh
   
# For each group aka grid cell extract average measures
for i in $(seq 1 $NCATS) 
do
echo Group $i: ${P[i]}
s=$(echo ${S[i]}|sed -e 's/ /,/g')
sql=`cat <<EOF |sed -e "s/@SENSOR_IDS@/${s}/"
select date(m.datetime) as ref_date,
	   avg(s.a*m.value+s.b) as avg,
	   stddev_pop(s.a*m.value+s.b) as stddev,
	   count(m.value) as ct,
	   min(m.depth_max) as Depth,
	   date(min(m.datetime)) as minMeasureDate,
	   strftime('%H:%M', min(m.datetime)) as minMeasureTime,
	   date(max(m.datetime)) as maxMeasureDate,
	   strftime('%H:%M', max(m.datetime)) as maxMeasureTime
from Measure as m,
	 Sensor as s
where m.count=0 and m.type = 'soil_moisture' and s.id = m.sensor_id and
	  m.depth_max <= 0.05 and m.datetime is not null and m.datetime != '' and
	  m.sensor_id in (@SENSOR_IDS@)
group by 1
order by ref_date; 
EOF
`

echo "Date|Mean Calibrated SM|Pop-StdDev Calibrated SM|Count|Max Depth(m)|Min Station Date|Time|Max Station Date|Time" >$D/${N}_${S}_ground_stats_bycell_G${i}.txt
echo $sql | spatialite -noheader $SM_TOOLS_DB >>${D}/${N}_${S}_ground_stats_bycell_G${i}.txt
done

exit 0
