#!/bin/sh

S=segezia
if [ $# -eq 1 ]; then
	S="$1"
fi

D=$SM_TOOLS_OUTPUTDIR
N=$(date +%Y%m%d)

net_id=$(spatialite -noheader $SM_TOOLS_DB "select id from Network where site_id in (select id from Site where name='$S')")
if [ -z "$net_id" ]
then
	echo "Network not found"
	exit 1
fi

echo $S

sql=`cat <<EOF
select s.name, 
	   date(m.datetime) as sd, 
	   strftime('%H',m.datetime) as sh, 
	   avg(s.a*m.value+s.b) as smean,
	   my_measure.m as sratio_mean,
	   (avg(s.a*m.value+s.b)-my_measure.m)/my_measure.m as sratio, 
	   count(m.value) as scount,
	   my_measure.c as sratio_count
from Measure as m, 
	(select date(datetime) as d,
			strftime('%H',datetime) as h, 
			count(value) as c, 
			avg(sens.a*value+sens.b) as m 
	from Measure, Sensor as sens 
	where Measure.type='soil_moisture' and 
		  sens.id=Measure.sensor_id and 
		  Measure.sensor_id in (select id from Sensor where network_id=${net_id}) and
		  Measure.depth_max<=0.05 and
		  Measure.value>-b/a
	group by 1,2) my_measure, 
	Sensor as s 
where m.type='soil_moisture' and 
m.sensor_id in (select id from Sensor where network_id=${net_id}) and 
	sd=my_measure.d and 
	sh=my_measure.h and 
	s.id=m.sensor_id and 
	m.depth_max<=0.05 and
	m.value>-b/a
group by 1,2,3 
order by 1,2,3;
EOF
`

# This is used to fill in the gaps in date/hour for all stations so that 
# The time window is the same for all of them.

echo "Sensor|Date|Hour|Hourly Sensor Mean|Hourly Site Mean|Ratio|Sensor count|Mean count" >${D}/${N}_${S}_tempostab_normalized.txt
cat >${D}/${N}_${S}_tempostab.pl <<'EOF'
use strict; 
use v5.18;

my $stations = {};
my $dates = {};
my $hours = {};
my $occurrences = {};
while (<DATA>) {
		chomp;
		my @fields = split /\|/;
		$stations->{$fields[0]} = $fields[0];
		$dates->{$fields[1]} = $fields[0];
		$hours->{$fields[2]} = $fields[0];
		$occurrences->{$fields[0]}->{$fields[1]}->{$fields[2]} = join('|', @fields[3 .. $#fields]);
}

for my $station (sort keys %$stations) {
	for my $date (sort keys %$dates) {
		for my $hour (sort keys %$hours) {
			my $val = defined $occurrences->{$station}->{$date}->{$hour} ? 
					  $occurrences->{$station}->{$date}->{$hour} : "||||";
			say "$station|$date|$hour|$val";
		}
	}
}


__DATA__
EOF
echo $sql | spatialite -noheader $SM_TOOLS_DB >>${D}/${N}_${S}_tempostab.pl
cat ${D}/${N}_${S}_tempostab.pl | perl >>${D}/${N}_${S}_tempostab_normalized.txt

exit 0
