#!/bin/bash
#
# This script has been used to extract SMAP values at each site centroid
# and for each available date, without distinction between AM and PM periods.
#

$SM_TOOLS/etc/grass_check.sh || exit 1

SKIP_IMPORT=1

if [ -z "$SKIP_IMPORT" ]
then
	# Import all SMAP images
	pushd /ocean/data/ESA-SEOM/SMAP36km
	for i in *.tif
	do
		b=$(basename $i .tif|awk -F_ '{print $1 "_" $5 "_" $9}')
		$G_EASE2 r.external -o --o in=$i out=$b 
		$G_EASE2 r.null setnull=-32768 map=$b 
	done
	popd
else
	echo "SMAP importing skipped"
fi

# Now for each site one can extract SMAP/SMOS cell size at any date
sites=$($G_EASE2 v.db.select -c sites_grids col=site)
for s in $sites
do
	echo "Site $s..."
	# Now each site grid cell in vector format can be used to select a single SMAP
	# raster cell as a 1x1 region 
	$G_EASE2 g.region vect=${s}_smap_grid res=36000 
	# This is the center of the cell
	eval $($G_EASE2 g.region -c -g)
	# and this is the value of raster map there 
	echo "date|spec|smap 36km" >$SM_TOOLS_OUTPUTDIR/${s}_smap_36km.txt
	for i in $($G_EASE2 g.list pat='SMAP_*' sep=' ' t=rast)
	do
		d=$(echo $i|cut -d_ -f2|perl -ne 'chomp; ($y,$m,$d) = unpack "A4A2A2", $_; print sprintf "%04d-%02d-%02d", $y, $m, $d;')
		z=$(echo $i|cut -d_ -f3)
		value=$($G_EASE2 r.what map=$i coordinates=$center_easting,$center_northing|cut -d\| -f4)
		if [ "$value" != '*' ]
		then
			echo "$d|$z|$value" >>$SM_TOOLS_OUTPUTDIR/${s}_smap_36km.txt
		fi
	done
done

exit 0
