#!/bin/sh
#
# This simple script filters SMAP/SMOS/ASCAT by using flags file 
# provided by Gamma GMBH and LMU.
#

$SM_TOOLS/etc/grass_check.sh || exit 1

set -e

#
# The following sections creates data dumps for Gamma maps.
#

OUTDIR=/net/milos/ocean/data/ESA-SEOM/FromGamma/filtered
FLAGSDIR=/net/milos/ocean/data/ESA-SEOM/FromGamma/flags

# SMAP

INDIR=/net/milos/ocean/data/ESA-SEOM/SMAP36km
cd $INDIR
mkdir -p $OUTDIR/SMAP36km || true
for f in $(ls *_sm_*.tif)
do
	D=$(echo $f|cut -d_ -f5)
	F1=$FLAGSDIR/${D}_smapflag.tif
	F2=$FLAGSDIR/${D}_rfiprob.tif
	if [ -f $F1 -a -f $F2 ] 
	then
		$G_EASE2 r.external -e in=$F1 out=smapflag --o
		$G_EASE2 r.external -e in=$F2 out=rfiprob --o
		$G_EASE2 r.external -e in=$f out=smap --o
		$G_EASE2 g.region rast=smap
		# Due to some oddities in NULL management in 7.x here isnull() is used 
		# to deal with smapflag nodata values.
		$G_EASE2 r.mapcalc --o <<EOF
MASK=if(rfiprob>=10.0,0,1)
filt=if(isnull(smapflag),smap,if(smapflag>=1,0.0,smap))
EOF
		$G_EASE2 r.null setnull=0 map=filt
		$G_EASE2 r.out.gdal -c -f type=Float32 in=filt out=$OUTDIR/SMAP36km/$f --o
		$G_EASE2 r.mask -r
		echo "Filtered $f"
	else
		echo "Missing flag files for $f"
		ln -f $f $OUTDIR/SMAP36km/$f
	fi
done

# SMOS
INDIR=/net/milos/ocean/data/ESA-SEOM/SMOS25km
cd $INDIR
mkdir -p $OUTDIR/SMOS25km || true
for f in $(ls *.tif)
do
	D=$(echo $f|cut -d_ -f5|cut -dT -f1)
	F1=$FLAGSDIR/${D}_smapflag.tif
	F2=$FLAGSDIR/${D}_rfiprob.tif
	if [ -f $F1 -a -f $F2 ] 
	then
		$G_EASE2 r.external -e in=$F1 out=smapflag --o
		$G_EASE2 r.external -e in=$F2 out=rfiprob --o
		$G_EASE2 r.external -e in=$f out=smos --o
		$G_EASE2 g.region rast=smos
		# Due to some oddities in NULL management in 7.x here isnull() is used 
		# to deal with smapflag nodata values.
		$G_EASE2 r.mapcalc --o <<EOF
MASK=if(rfiprob>=10.0,0,1)
filt=if(isnull(smapflag),smos,if(smapflag>=1,0.0,smos))
EOF
		$G_EASE2 r.null setnull=0 map=filt
		$G_EASE2 r.out.gdal -c -f type=Float32 in=filt out=$OUTDIR/SMOS25km/$f --o
		$G_EASE2 r.mask -r
		echo "Filtered $f"
	else
		echo "Missing flag files for $f"
		ln -f $f $OUTDIR/SMOS25km/$f
	fi
done

# ASCAT
INDIR=/net/milos/ocean/data/ESA-SEOM/ASCAT12.5km
cd $INDIR
mkdir -p $OUTDIR/ASCAT12.5km || true
for f in $(ls *.tif)
do
	D=$(echo $f|cut -d_ -f1)
	F1=$FLAGSDIR/${D}_smapflag.tif
	F2=$FLAGSDIR/${D}_rfiprob.tif
	if [ -f $F1 -a -f $F2 ] 
	then
		$G_EASE2 r.external -e in=$F1 out=smapflag --o
		$G_EASE2 r.external -e in=$F2 out=rfiprob --o
		$G_EASE2 r.external -e in=$f out=ascat --o
		$G_EASE2 g.region rast=ascat
		# Due to some oddities in NULL management in 7.x here isnull() is used 
		# to deal with smapflag nodata values.
		$G_EASE2 r.mapcalc --o <<EOF
MASK=if(rfiprob>=10.0,0,1)
filt=if(isnull(smapflag),ascat,if(smapflag>=1,0.0,ascat))
EOF
		$G_EASE2 r.null setnull=0 map=filt
		$G_EASE2 r.out.gdal -c -f type=Float32 in=filt out=$OUTDIR/ASCAT12.5km/$f --o
		$G_EASE2 r.mask -r
		echo "Filtered $f"
	else
		echo "Missing flag files for $f"
		ln -f $f $OUTDIR/ASCAT12.5km/$f
	fi
done

exit 0
