#!/bin/sh

set -e

if [ $# -lt 2 ]
then
	echo "usage: $0 resolution track"
	exit 1
fi

$SM_TOOLS/etc/grass_check.sh || exit 2

res=$1
# FIXME: the track name is dependent on SMOSAR pathnames :-/
#track=$2
#track=Medi_$2
track=Remedhus_$2

case $res in
	1D)
		res=1
		t=DSMAP$res
		dir=/net/milos/ocean/data/ESA-SEOM/FromLMU/SMAP_DOWNSCALED/tif
		pat="*.tif"
		type="tif"
		;;
	1)
		t=SMAP$res
		dir=/net/milos/ocean/data/ESA-SEOM/SMAP1km_S1
		pat="SMAP*.tif"
		type="am"
		;;
	4)
		t=SMAP$res
		dir=/net/milos/ocean/data/ESA-SEOM/SMAP3km_S1
		pat="SMAP*.tif"
		type="am"
		;;
	9)
		t=SMAP$res
		dir=/net/milos/ocean/data/ESA-SEOM/FromGamma/SMAP_10km
		#dir=/net/milos/ocean/data/ESA-SEOM/FromGamma/SMAP_9km_radiometer/SMP_E_9km_20180809
		pat="SMAP_L3_SM_P_E_*.tif"
		type="_am"
		;;
	25)
		t=SMOS
		dir=/net/milos/ocean/data/ESA-SEOM/SMOS25km
		#dir=/net/milos/ocean/data/ESA-SEOM/filtered/SMOS25km
		pat="SM*.tif"
		type="CLF31A"
		;;
	36)
		t=SMAP$res
		#dir=/net/milos/ocean/data/ESA-SEOM/filtered/SMAP36km
		dir=/net/milos/ocean/data/ESA-SEOM/SMAP36km
		pat="SMAP*.tif"
		type="am"
		;;
	12d5)
		t=ASCAT
		dir=/net/milos/ocean/data/ESA-SEOM/ascat_volsm
		#dir=/net/milos/ocean/data/ESA-SEOM/filtered/ASCAT12.5km
		pat="*_ascat.tif"
		type="am"
		;;
	*)
		echo "$0: wrong resolution used"
		exit 3
		;;
esac

cd $dir

TEMPFILE=$(mktemp -q)

for file in $(ls $pat|grep $type)
do
	f=$(basename $file .tif)
	case $t in
		DSMAP1)
			isodate=$f
			;;
		SMAP1)
			isodate=$(echo $f|cut -d_ -f2)
			;;
		SMAP3)
			isodate=$(echo $f|cut -d_ -f2)
			;;
		SMAP9)
			isodate=$(echo $f|cut -d_ -f6)
			;;
		SMAP36)
			isodate=$(echo $f|cut -d_ -f5)
			;;
		SMAP)
			isodate=$(echo $f|cut -d_ -f5)
			;;
		SMOS)
			isodate=$(echo $f|cut -d_ -f5|cut -dT -f1)
			;;
		ASCAT)
			isodate=$(echo $f|cut -d_ -f1)
			;;
	esac
	$G_EASE2 g.mapsets op=add mapset=SM_TOOLS
	$G_EASE2 r.external in=$file out=$f --o
	mkdir -p $SM_TOOLS_OUTPUTDIR/smap_grids_sampling 2>/dev/null || true
	$G_EASE2 g.region --quiet rast=$f
	$G_EASE2 v.out.ascii type=centroid in=smap_grid_${res}km_${track} sep=space >$TEMPFILE
	cat $TEMPFILE|$G_EASE2 r.what null=0 map=$f cache=10000 --qq| \
		sed -e 's/-32768/0/' -e 's/-32767/0/'|cut -d\| -f3,4 >$SM_TOOLS_OUTPUTDIR/smap_grids_sampling/${t}_${isodate}_${track}.txt
done

rm -f $TEMPFILE

exit 0


