#!/bin/bash
#
# This script has been used to extract SMOS values at each site centroid
# and for each available date, without distinction between ascending and
# descending orbits.
#

$SM_TOOLS/etc/grass_check.sh || exit 1

SKIP_IMPORT=1

# Extracted from metadata, check consistency before use!
scale_factor=3.05185094759971e-05

if [ -z "$SKIP_IMPORT" ]
then
	# Import all SMOS images
	pushd /ocean/data/ESA-SEOM/SMOS25km
	for i in *CLF31A*_sm.tif
	do
		b=$(basename $i .tif|awk -F_ '{print "SMOS_" $5 }'|cut -dT -f1)
		$G_EASE2 r.external -o --o in=$i out=${b}_asc 
		$G_EASE2 r.null setnull=$(gdalinfo $i| grep -i nodata | cut -d= -f2) map=${b}_asc
	done
	for i in *CLF31D*_sm.tif
	do
		b=$(basename $i .tif|awk -F_ '{print "SMOS_" $5 }'|cut -dT -f1)
		$G_EASE2 r.external -o --o in=$i out=${b}_desc
		$G_EASE2 r.null setnull=$(gdalinfo $i| grep -i nodata | cut -d= -f2) map=${b}_desc
	done
	popd
else
	echo "SMOS importing skipped"
fi

# Now for each site one can extract SMAP/SMOS cell size at any date
sites=$($G_EASE2 v.db.select -c sites_grids col=site)
for s in $sites
do
	echo "Site $s..."
	# Now each site grid cell in vector format can be used to select a single SMAP
	# raster cell as a 1x1 region 
	$G_EASE2 g.region vect=${s}_smos_grid res=25025.2600081 
	# This is the center of the cell
	eval $($G_EASE2 g.region -c -g)
	# and this is the value of raster map there 
	echo "date|spec|smos 25km" >$SM_TOOLS_OUTPUTDIR/${s}_smos_25km.txt
	for i in $($G_EASE2 g.list pat='SMOS_*' sep=' ' t=rast)
	do
		d=$(echo $i|cut -d_ -f2|perl -ne 'chomp; ($y,$m,$d) = unpack "A4A2A2", $_; print sprintf "%04d-%02d-%02d", $y, $m, $d;')
		z=$(echo $i|cut -d_ -f3)
		value=$($G_EASE2 r.what map=$i coordinates=$center_easting,$center_northing|cut -d\| -f4)
		if [ "$value" != '*' ]
		then
			value=$(perl -e "print $value*$scale_factor,qq/\n/")
			echo "$d|$z|$value" >>$SM_TOOLS_OUTPUTDIR/${s}_smos_25km.txt
		fi
	done
done

exit 0
