#!/bin/sh
#
# This tiny script is used to cut and reproject original SMAP images provided
# by GAMMA Gmbh into a target frame geometry.
#

$SM_TOOLS/etc/grass_check.sh || exit 1
 
if [ -z "$(which pkinfo)" ]; then
	echo "Missing pktools"
	exit 1
fi

if [ $# -lt 4 ]
then
	echo "usage: $0 reference_frame output_file_name date am|pm"
	exit 1
fi
TARGET=$1
OUTPUT=$2
DATE=$3
DIR=$4

case $DIR in
	am)
		rel='<'
		;;
	pm)
		rel='>='
		;;
	*)
		"am|pm is mandatory for the last argument"
		;;
esac

TEMPDIR=$(mktemp -dq)

set -e


SMAP=$(spatialite -batch -noheader $SM_TOOLS_DB <<EOF
select filename from Product 
where product_type='SM SMAP 36km' and
strftime('%Y%m%d',reference_datetime)='$DATE' and
cast(strftime('%H',reference_datetime) as integer) $rel 12;
EOF
)

$G r.external in=$TARGET out=target --o
$G g.region -a rast=target
nsres=$($G g.region -p -g|grep nsres|cut -d= -f2)
ewres=$($G g.region -p -g|grep ewres|cut -d= -f2)
ext=$(pkinfo -i $TARGET -te|cut -d\  -f2-)
gdalwarp -overwrite -tr $ewres $nsres -te $ext -t_srs EPSG:4326 -of ENVI \
	 $SM_TOOLS_REPO/$SMAP $TEMPDIR/SMAP
$G r.external in=$TEMPDIR/SMAP out=smap --o
$G r.mapcalc expr="result=smap" --o
$G r.out.gdal format=ENVI in=result out=$OUTPUT --o
$G g.remove t=rast name=target,result,smap -f

rm -rf $TEMPDIR

exit 0
