#!/bin/sh
#
# This tiny script is used to cut and reproject original SMAP images provided
# by GAMMA Gmbh into a target frame geometry.
# 
# This is updated to work with gdal 2.4+
#

if [ $# -lt 4 ]
then
	echo "usage: $0 reference_frame output_file_name date am|pm"
	exit 1
fi

if [ -z "$(which pkinfo)" ]; then
	echo "Missing pktools"
	exit 1
fi

TARGET=$1
OUTPUT=$2
DATE=$3
DIR=$4

case $DIR in
	am)
		rel='<'
		;;
	pm)
		rel='>='
		;;
	*)
		"am|pm is mandatory for the last argument"
		;;
esac

set -e

SMAP=$(spatialite -batch -noheader $SM_TOOLS_DB <<EOF
select filename from Product 
where product_type='SM SMAP 36km' and
strftime('%Y%m%d',reference_datetime)='$DATE' and
cast(strftime('%H',reference_datetime) as integer) $rel 12;
EOF
)

RES=$(pkinfo -i $TARGET -dx -dy|cut -d\  -f2,4)
EXT=$(pkinfo -i $TARGET -te|cut -d\  -f2-)
gdalwarp -overwrite -tr $RES -te $EXT -t_srs EPSG:4326 -of ENVI -r bilinear $SM_TOOLS_REPO/$SMAP $OUTPUT

exit 0
