#!/bin/sh
#
# This script create a soil texture map aligned to a reference frame, reporting also
# information about the resulting USDA data.
# This vesion is updated for use of GDAL 2.4+ 
#

set -e

CLAY=$SM_TOOLS_TEXTURE/CLYPPT_M_sl1_250m.tif
SAND=$SM_TOOLS_TEXTURE/SNDPPT_M_sl1_250m.tif

if [ -z "$(which pkinfo)" ]; then
	echo "Missing pktools"
	exit 1
fi
 
if [ $# -lt 2 ]
then
	echo "usage: $0 target_image output_name"
	exit 1
fi
TARGET=$1
OUTPUT=$2

$G r.external in=$TARGET out=target --o
$G g.region rast=target
EXT=$(pkinfo -i $TARGET -te|cut -d\  -f2-)
gdalwarp -overwrite -te $EXT -tr $(pkinfo -i $SAND -dx -dy|cut -d\  -f2,4) $SAND $SM_TOOLS_TMPDIR/sand
gdalwarp -overwrite -te $EXT -tr $(pkinfo -i $CLAY -dx -dy|cut -d\  -f2,4) $CLAY $SM_TOOLS_TMPDIR/clay
$G r.external in=$SM_TOOLS_TMPDIR/sand out=SAND --o
$G r.external in=$SM_TOOLS_TMPDIR/clay out=CLAY --o

$G r.soils.texture sand=SAND clay=CLAY out=texture scheme=$SM_TOOLS/etc/USDA.dat --o
$G r.null setnull=0 map=texture
$G r.out.gdal -t in=texture out=$OUTPUT
$G r.report -n -h map=texture >$OUTPUT.txt

exit 0
