#!/bin/bash

# These masks refer to July 2018, as extracted from NDVI with different thresholds
# They should correspond to different approximations of irrigated fields in raster representation.

set -e

TAG=sigma0_asc
YEAR1=2017
YEAR2=2018
OUTDIR=$SM_TOOLS/streams_crossing/results
REGION="POLYGON ((16.2394539655556 40.7728148486111,15.0709864105556 40.7728148486111,15.0709864105556 41.9181865016667,16.2394539655556 41.9181865016667,16.2394539655556 40.7728148486111))"

$G g.region rast=italy_fully_merged_fields_2017_reclumped

# Valid crops are: Tomato Maize Brocoli Fennel Durum Wheat,Artichoke,Asparagus,Pepper,Spinach

for CROP in Tomato Artichoke Brocoli Fennel Asparagus Spinach
do

$G v.to.rast in=italy_irrigated_2017 out=cra_2017 use=cat where="Crop_EN in ('$CROP')"  --o
$G v.to.rast in=italy_irrigated_2018 out=cra_2018 use=cat where="Crop_EN in ('$CROP')"  --o

SSM1=$(spatialite -batch -noheader $SM_TOOLS_DB<<EOF
select filename,date(reference_datetime) from ProcessedImage where tag='$TAG' and strftime('%Y',reference_datetime)='$YEAR1' and strftime('%m',reference_datetime) in ('04','05','06','07') and
ST_Intersects(boundingbox,ST_GeomFromText('$REGION',4326))>0;
EOF
)
SSM2=$(spatialite -batch -noheader $SM_TOOLS_DB<<EOF
select filename,date(reference_datetime) from ProcessedImage where tag='$TAG' and strftime('%Y',reference_datetime)='$YEAR2' and strftime('%m',reference_datetime) in ('04','05','06','07') and
ST_Intersects(boundingbox,ST_GeomFromText('$REGION',4326))>0;
EOF
)

R1=$(mktemp -q)
R2=$(mktemp -q)
R3=$(mktemp -q)
R4=$(mktemp -q)

echo "cat|date|avg|stddev" >$OUTDIR/S0_italy_cra_irrigated_${YEAR1}_${CROP}_stats.txt
echo "cat|date|avg|stddev" >$OUTDIR/S0_italy_cra_irrigated_${YEAR2}_${CROP}_stats.txt

for l in $SSM1
do
	f=$(echo $l|cut -d\| -f1)
	d=$(echo $l|cut -d\| -f2)
	$G r.external in=$SM_TOOLS_REPO/$f out=$f --o
	$G r.null setnull=0 map=$f

	$G r.stats.zonal2 -r base=cra_$YEAR1 cover=$f rules=$R1 method=average out=SSM_mean_$YEAR1 --o
	$G r.stats.zonal2 -r base=cra_$YEAR1 cover=$f rules=$R3 method=stddev2 out=SSM_stddev_$YEAR1 --o
	for cat in $($G r.category map=cra_$YEAR1|cut -f1)
	do
		val=$(egrep "^$cat = " $R1|cut -d' ' -f4|sed -e 's/-0.000000/0.000000/')
		sd=$(egrep "^$cat = " $R3|cut -d' ' -f4|sed -e 's/-nan/NA/')
		if [ ! -z "$val" ]
		then
			echo "$cat|$d|$val|$sd"	>>$OUTDIR/S0_italy_cra_irrigated_${YEAR1}_${CROP}_stats.txt
		fi
	done
done

for l in $SSM2
do
	f=$(echo $l|cut -d\| -f1)
	d=$(echo $l|cut -d\| -f2)
	$G r.external in=$SM_TOOLS_REPO/$f out=$f --o
	$G r.null setnull=0 map=$f

	$G r.stats.zonal2 -r base=cra_$YEAR2 cover=$f rules=$R2 method=average out=SSM_mean_$YEAR2 --o
	$G r.stats.zonal2 -r base=cra_$YEAR2 cover=$f rules=$R4 method=stddev2 out=SSM_stddev_$YEAR2 --o
	for cat in $($G r.category map=cra_$YEAR2|cut -f1)
	do
		val=$(egrep "^$cat = " $R2|cut -d' ' -f4|sed -e 's/-0.000000/0.000000/')
		sd=$(egrep "^$cat = " $R4|cut -d' ' -f4|sed -e 's/-nan/NA/')
		if [ ! -z "$val" ]
		then
			echo "$cat|$d|$val|$sd"	>>$OUTDIR/S0_italy_cra_irrigated_${YEAR2}_${CROP}_stats.txt
		fi
	done
done

rm -f $R1 $R2 $R3 $R4


done

exit 0
