#!/bin/bash

# These masks refer to July 2018, as extracted from NDVI with different thresholds
# They should correspond to different approximations of irrigated fields in raster representation.

set -e

TAG=p_ssm_img_zs_mean_run_n4_v1_2_20190331_asc
YEAR=2018
OUTDIR=$SM_TOOLS/streams_crossing/results

$G g.region rast=italy_fully_merged_fields_2017_reclumped
if [ $($G g.list t=rast pat='italy_veg0?'|wc -l) -ne 2 ]
then
	$G g.copy vect=italy_fully_merged_fields_2017_reclumped,italy_polygons --o
	$G v.rast.stats map=italy_polygons rast=italy_fully_merged_fields_2017_reclumped method=number col=area 
	$G v.rast.stats map=italy_polygons rast=italy_ndvi_mask_04_1ha method=number col=veg04 
	$G v.rast.stats map=italy_polygons rast=italy_ndvi_mask_06_1ha method=number col=veg06 

	$G v.to.rast in=italy_polygons where='veg06_number/area_number>=0.9' out=italy_veg06 type=area use=cat mem=3000 --o
	$G v.to.rast in=italy_polygons where='veg04_number/area_number>=0.9' out=italy_veg04 type=area use=cat mem=3000 --o

	$G v.to.rast in=italy_polygons where='veg06_number/area_number<=0.1' out=italy_noveg06 type=area use=cat mem=3000 --o
	$G v.to.rast in=italy_polygons where='veg04_number/area_number<=0.1' out=italy_noveg04 type=area use=cat mem=3000 --o
#
#	pushd /ocean/SMOSAR/S-1_SSM_RA/Maps_Products/NDVI/ApulianTav_S1_A146_S1_GTC_MN02_RL4200_mask_jul2018/
#	$G r.out.gdal in=italy_veg04 out=italy_irrigated04 
#	$G r.out.gdal in=italy_veg06 out=italy_irrigated06 
#	popd
#
fi

SSM=$(spatialite -batch -noheader $SM_TOOLS_DB<<EOF
select filename,date(reference_datetime) from Product where tag='$TAG' and strftime('%Y',reference_datetime)='$YEAR' and strftime('%m',reference_datetime) in ('05','07');
EOF
)

R1=$(mktemp -q)
R2=$(mktemp -q)
R3=$(mktemp -q)
R4=$(mktemp -q)

echo "cat|date|SSM" >$OUTDIR/SSM_italy_irrigated04_stats.txt
echo "cat|date|SSM" >$OUTDIR/SSM_italy_irrigated06_stats.txt
echo "cat|date|SSM" >$OUTDIR/SSM_italy_notirrigated04_stats.txt
echo "cat|date|SSM" >$OUTDIR/SSM_italy_notirrigated06_stats.txt

for l in $SSM
do
	f=$(echo $l|cut -d\| -f1)
	d=$(echo $l|cut -d\| -f2)
	$G r.external in=$SM_TOOLS_REPO/$f out=$f --o

	$G r.stats.zonal2 -r base=italy_veg04 cover=$f rules=$R1 method=average out=SSM_mean --o	
	for cat in $($G r.category map=italy_veg04|cut -f1)
	do
		val=$(egrep "^$cat = " $R1|cut -d' ' -f4|sed -e 's/-nan/NA/'|sed -e 's/0.000000//')
		if [ ! -z "$val" ]
		then
			echo "$cat|$d|$val"	>>$OUTDIR/SSM_italy_irrigated04_stats.txt
		fi
	done
	$G r.stats.zonal2 -r base=italy_veg06 cover=$f rules=$R2 method=average out=SSM_mean --o
	for cat in $($G r.category map=italy_veg06|cut -f1)
	do
		val=$(egrep "^$cat = " $R1|cut -d' ' -f4|sed -e 's/-nan/NA/'|sed -e 's/0.000000//')
		if [ ! -z "$val" ]
		then
			echo "$cat|$d|$val"	>>$OUTDIR/SSM_italy_irrigated06_stats.txt
		fi
	done

	$G r.stats.zonal2 -r base=italy_noveg04 cover=$f rules=$R3 method=average out=SSM_mean --o	
	for cat in $($G r.category map=italy_noveg04|cut -f1)
	do
		val=$(egrep "^$cat = " $R3|cut -d' ' -f4|sed -e 's/-nan/NA/'|sed -e 's/0.000000//')
		if [ ! -z "$val" ]
		then
			echo "$cat|$d|$val"	>>$OUTDIR/SSM_italy_notirrigated04_stats.txt
		fi
	done
	$G r.stats.zonal2 -r base=italy_noveg06 cover=$f rules=$R4 method=average out=SSM_mean --o
	for cat in $($G r.category map=italy_noveg06|cut -f1)
	do
		val=$(egrep "^$cat = " $R4|cut -d' ' -f4|sed -e 's/-nan/NA/'|sed -e 's/0.000000//')
		if [ ! -z "$val" ]
		then
			echo "$cat|$d|$val"	>>$OUTDIR/SSM_italy_notirrigated06_stats.txt
		fi
	done
done

rm -f $R1 $R2 $R3 $R4

exit 0
