#!/bin/sh
#
# This scripts extracts zonal statistics for NDVI maps in Apulian Tavoliere
# using base land cover maps for the area which is available in different months.
#

set -e

LC=apuliantavoliere
OUTDIR=$SM_TOOLS/streams_crossing/results
MINCELLS=1
CLAY=$SM_TOOLS_TEXTURE/CLYPPT_M_sl1_250m.tif
SAND=$SM_TOOLS_TEXTURE/SNDPPT_M_sl1_250m.tif
YEAR=2017
R_CNT=$(mktemp -q)
RES=$(pkinfo -dx -i $SAND|cut -d' ' -f2)
 
# a pair of silly functions ...
getcat() {
	if [ $1 -ge 100000 ]; then
		echo $(expr $1 - 100000)
		return
	fi
	if [ $1 -ge 90000 ]; then
		echo $(expr $1 - 90000)
		return
	fi
	if [ $1 -ge 80000 ]; then
		echo $(expr $1 - 80000)
		return
	fi
	if [ $1 -ge 70000 ]; then
		echo $(expr $1 - 70000)
		return
	fi
	if [ $1 -ge 60000 ]; then
		echo $(expr $1 - 60000)
		return
	fi
	if [ $1 -ge 50000 ]; then
		echo $(expr $1 - 50000)
		return
	fi
	if [ $1 -ge 40000 ]; then
		echo $(expr $1 - 40000)
		return
	fi
	if [ $1 -ge 30000 ]; then
		echo $(expr $1 - 30000)
		return
	fi
}

getmap() {
	if [ $1 -ge 100000 ]; then
		echo ${LC}_10$YEAR
		return
	fi
	if [ $1 -ge 90000 ]; then
		echo ${LC}_09$YEAR
		return
	fi
	if [ $1 -ge 80000 ]; then
		echo ${LC}_08$YEAR
		return
	fi
	if [ $1 -ge 70000 ]; then
		echo ${LC}_07$YEAR
		return
	fi
	if [ $1 -ge 60000 ]; then
		echo ${LC}_06$YEAR
		return
	fi
	if [ $1 -ge 50000 ]; then
		echo ${LC}_05$YEAR
		return
	fi
	if [ $1 -ge 40000 ]; then
		echo ${LC}_04$YEAR
		return
	fi
	if [ $1 -ge 30000 ]; then
		echo ${LC}_03$YEAR
		return
	fi
}

$G g.region res=$RES vect=$(g.list t=vect pat="${LC}_*$YEAR" sep=,)
$G v.mkgrid map=GRID pos=region grid=1,1 --o
$G v.out.ogr out=$SM_TOOLS_TMPDIR/grid.shp in=GRID type=area --o
gdalwarp -overwrite  -wo 'CUTLINE_ALL_TOUCHED=TRUE' -of ENVI -cutline $SM_TOOLS_TMPDIR/grid.shp -crop_to_cutline $SAND $SM_TOOLS_TMPDIR/sand
gdalwarp -overwrite  -wo 'CUTLINE_ALL_TOUCHED=TRUE' -of ENVI -cutline $SM_TOOLS_TMPDIR/grid.shp -crop_to_cutline $CLAY $SM_TOOLS_TMPDIR/clay
$G r.external in=$SM_TOOLS_TMPDIR/sand out=SAND --o
$G r.external in=$SM_TOOLS_TMPDIR/clay out=CLAY --o

# spring 

for m in $(perl -e 'for $i (6..10) {printf "%02d\n",$i}')
do
	$G v.to.rast in=${LC}_${m}${YEAR} out=${LC}_${m}$YEAR use=cat label=crop_en mem=8000 --o
done
for m in $(perl -e 'for $i (6..10) {printf "%02d\n",$i}')
do
	ofs=$(expr 10000 \* $m)
	$G r.mapcalc expr="${LC}_${m}${YEAR}_$ofs = ${LC}_${m}${YEAR} + $ofs" --o
done

# consolidating multiple LCs, this is site specific :-/ do we need to save them?
$G r.patch in="${LC}_062017_60000,${LC}_072017_70000,${LC}_082017_80000,${LC}_092017_90000,${LC}_102017_100000" out=${LC}_spring --o

for season in spring 
do
	$G r.soils.texture sand=SAND clay=CLAY out=texture scheme=$SM_TOOLS/etc/USDA.dat --o
	$G r.null setnull=0 map=texture
	$G r.stats.zonal2 -r base=${LC}_$season cover=texture rules=$R_CNT method=count out=texture_count --o
	$G r.statistics base=${LC}_$season cover=texture method=mode out=texture_mode --o
	$G r.statistics base=${LC}_$season cover=texture method=diversity out=texture_div --o
	echo "map|cat|count|crop|texture|diversity" >$OUTDIR/SOIL_${LC}_${season}_stats.txt
	for l in $($G r.category map=${LC}_$season sep=\||cut -d\| -f1) 
	do
		count=$(egrep "^$l =" $R_CNT|cut -d' ' -f4|cut -d. -f1)
		# skip when number of cells is too low
		if [ $count -ge $MINCELLS ]
		then
			cat=$(getcat $l)
			map=$(getmap $l)
			crop=$($G r.category map=$map cat=$cat sep=\||cut -d\| -f2)
			mode=$($G r.category map=texture_mode cat=$l sep=\||cut -d\| -f2)
			div=$($G r.category map=texture_div cat=$l sep=\||cut -d\| -f2)
			text=$($G r.category map=texture cat=$mode sep=\||cut -d\| -f2)
			echo "$map|$cat|$count|$crop|$text|$div" >>$OUTDIR/SOIL_${LC}_${season}_stats.txt
		fi
	done
done

# winter

for m in $(perl -e 'for $i (3..5) {printf "%02d\n",$i}')
do
	$G v.to.rast in=${LC}_${m}${YEAR} out=${LC}_${m}$YEAR use=cat label=crop_en mem=8000 --o
done
for m in $(perl -e 'for $i (3..5) {printf "%02d\n",$i}')
do
	ofs=$(expr 10000 \* $m)
	$G r.mapcalc expr="${LC}_${m}${YEAR}_$ofs = ${LC}_${m}$YEAR + $ofs" --o
done

# consolidating multiple LCs, this is site specific :-/ do we need to save them?
$G r.patch in="${LC}_052017_50000,${LC}_042017_40000,${LC}_032017_30000" out=${LC}_winter --o

for season in winter 
do
	$G r.soils.texture sand=SAND clay=CLAY out=texture scheme=$SM_TOOLS/etc/USDA.dat --o
	$G r.null setnull=0 map=texture
	$G r.stats.zonal2 -r base=${LC}_$season cover=texture rules=$R_CNT method=count out=texture_count --o
	$G r.statistics base=${LC}_$season cover=texture method=mode out=texture_mode --o
	$G r.statistics base=${LC}_$season cover=texture method=diversity out=texture_div --o
	echo "map|cat|count|crop|texture|diversity" >$OUTDIR/SOIL_${LC}_${season}_stats.txt
	for l in $($G r.category map=${LC}_$season sep=\||cut -d\| -f1) 
	do
		count=$(egrep "^$l =" $R_CNT|cut -d' ' -f4|cut -d. -f1)
		# skip when number of cells is too low
		if [ $count -ge $MINCELLS ]
		then
			cat=$(getcat $l)
			map=$(getmap $l)
			crop=$($G r.category map=$map cat=$cat sep=\||cut -d\| -f2)
			mode=$($G r.category map=texture_mode cat=$l sep=\||cut -d\| -f2)
			div=$($G r.category map=texture_div cat=$l sep=\||cut -d\| -f2)
			text=$($G r.category map=texture cat=$mode sep=\||cut -d\| -f2)
			echo "$map|$cat|$count|$crop|$text|$div" >>$OUTDIR/SOIL_${LC}_${season}_stats.txt
		fi
	done
done

rm -f $R_CNT

$G_CLEAN
