#!/bin/sh
#
# This scripts extracts zonal statistics for SSM maps in Italy
# using base land cover maps for the area which is available in different months.
# All LC are pre-loaded.
#

TAG=p40_mv_img_run_n4_v7_6_20190128_asc
LC=apuliantavoliere
OUTDIR=$SM_TOOLS/streams_crossing/results
SSM_BANDS=1

# The SSM maps are 40x40m^2 wide.
MINCELLS=7

# a pair of silly functions ...
getcat() {
	if [ $1 -ge 100000 ]; then
		echo $(expr $1 - 100000)
		return
	fi
	if [ $1 -ge 90000 ]; then
		echo $(expr $1 - 90000)
		return
	fi
	if [ $1 -ge 80000 ]; then
		echo $(expr $1 - 80000)
		return
	fi
	if [ $1 -ge 70000 ]; then
		echo $(expr $1 - 70000)
		return
	fi
	if [ $1 -ge 60000 ]; then
		echo $(expr $1 - 60000)
		return
	fi
	if [ $1 -ge 50000 ]; then
		echo $(expr $1 - 50000)
		return
	fi
	if [ $1 -ge 40000 ]; then
		echo $(expr $1 - 40000)
		return
	fi
	if [ $1 -ge 30000 ]; then
		echo $(expr $1 - 30000)
		return
	fi
}

getmap() {
	if [ $1 -ge 100000 ]; then
		echo ${LC}_102017
		return
	fi
	if [ $1 -ge 90000 ]; then
		echo ${LC}_092017
		return
	fi
	if [ $1 -ge 80000 ]; then
		echo ${LC}_082017
		return
	fi
	if [ $1 -ge 70000 ]; then
		echo ${LC}_072017
		return
	fi
	if [ $1 -ge 60000 ]; then
		echo ${LC}_062017
		return
	fi
	if [ $1 -ge 50000 ]; then
		echo ${LC}_052017
		return
	fi
	if [ $1 -ge 40000 ]; then
		echo ${LC}_042017
		return
	fi
	if [ $1 -ge 30000 ]; then
		echo ${LC}_032017
		return
	fi
}

R_CNT=$(mktemp -q)
R_MIN=$(mktemp -q)
R_MAX=$(mktemp -q)
R_AVG=$(mktemp -q)
R_STD=$(mktemp -q)
R_SKW=$(mktemp -q)
R_KUR=$(mktemp -q)

# winter LC

ROWS=$(spatialite -batch -noheader $SM_TOOLS_DB <<EOF
select p.filename,date(p.reference_datetime) from Product as p, Site as s 
where p.tag='$TAG' and strftime('%Y',p.reference_datetime)='2017' 
and cast(strftime('%m',reference_datetime) as integer) <= 5 
and s.id=1 and ST_Intersects(p.footprint,s.aoi)>0;
EOF
)

for r in $ROWS
do
	f=$(echo $r|cut -d\| -f1)
	d=$(echo $r|cut -d\| -f2)
	for i in $SSM_BANDS
	do
		echo "SSM $d $i" 
		if [ -f $OUTDIR/SSM_${d}_${i}_${LC}_winter_stats.txt ] 
		then 
			continue
		fi

		SSM=$SM_TOOLS_REPO/$f
		$G r.in.gdal band=$i in=$SSM out=SSM --o
		$G r.null setnull=0 map=SSM
		$G g.region rast=SSM 

		for m in $(perl -e 'for $i (3..5) {printf "%02d\n",$i}')
		do
			$G v.to.rast in=${LC}_${m}2017 out=${LC}_${m}2017 use=cat label=crop_en mem=8000 --o
		done
		for m in $(perl -e 'for $i (3..5) {printf "%02d\n",$i}')
		do
			ofs=$(expr 10000 \* $m)
			$G r.mapcalc expr="${LC}_${m}2017_$ofs = ${LC}_${m}2017 + $ofs" --o
		done

		# consolidating multiple LCs, this is site specific :-/ do we need to save them?
		$G r.patch in="${LC}_052017_50000,${LC}_042017_40000,${LC}_032017_30000" out=${LC}_winter --o

		for season in winter 
		do
			$G r.stats.zonal2 -r base=${LC}_$season cover=SSM rules=$R_CNT method=count out=SSM_count --o
			$G r.stats.zonal2 -r base=${LC}_$season cover=SSM rules=$R_MIN method=min out=SSM_min --o
			$G r.stats.zonal2 -r base=${LC}_$season cover=SSM rules=$R_MAX method=max out=SSM_max --o
			$G r.stats.zonal2 -r base=${LC}_$season cover=SSM rules=$R_AVG method=average out=SSM_mean --o
			$G r.stats.zonal2 -r base=${LC}_$season cover=SSM rules=$R_STD method=stddev2 out=SSM_stddev --o
			$G r.stats.zonal2 -r base=${LC}_$season cover=SSM rules=$R_SKW method=skewness2 out=SSM_skewness --o
			$G r.stats.zonal2 -r base=${LC}_$season cover=SSM rules=$R_KUR method=kurtosis2 out=SSM_kurtosis --o
			echo "map|cat|crop|count|min|max|avg|stddev|skew|kurt" >$OUTDIR/SSM_${d}_${i}_${LC}_${season}_stats.txt
			for l in $($G r.category map=${LC}_$season sep=\||cut -d\| -f1) 
			do
				count=$(egrep "^$l =" $R_CNT|cut -d' ' -f4|cut -d. -f1)
				# skip when number of cells is too low
				if [ $count -ge $MINCELLS ]
				then
					cat=$(getcat $l)
					map=$(getmap $l)
					crop=$($G r.category map=$map cat=$cat sep=\||cut -d\| -f2)
					min=$(egrep "^$l =" $R_MIN|cut -d' ' -f4|sed -e 's/-nan/NA/')
					max=$(egrep "^$l =" $R_MAX|cut -d' ' -f4|sed -e 's/-nan/NA/')
					avg=$(egrep "^$l =" $R_AVG|cut -d' ' -f4|sed -e 's/-nan/NA/')
					stddev=$(egrep "^$l =" $R_STD|cut -d' ' -f4|sed -e 's/-nan/NA/')
					skew=$(egrep "^$l =" $R_SKW|cut -d' ' -f4|sed -e 's/-nan/NA/')
					kurt=$(egrep "^$l =" $R_KUR|cut -d' ' -f4|sed -e 's/-nan/NA/')
					echo "$map|$cat|$crop|$count|$min|$max|$avg|$stddev|$skew|$kurt" >>$OUTDIR/SSM_${d}_${i}_${LC}_${season}_stats.txt
				fi
			done
		done
	done
done

# spring LC

ROWS=$(spatialite -batch -noheader $SM_TOOLS_DB <<EOF
select p.filename,date(p.reference_datetime) from Product as p, Site as s 
where p.tag='$TAG' and strftime('%Y',p.reference_datetime)='2017' and 
cast(strftime('%m',reference_datetime) as integer) > 5 
and s.id=1 and ST_Intersects(p.footprint,s.aoi)>0;
EOF
)

for r in $ROWS
do
	f=$(echo $r|cut -d\| -f1)
	d=$(echo $r|cut -d\| -f2)
	for i in 1 #$(seq 9)
	do
		echo "SSM $d $i" 
		if [ -f $OUTDIR/SSM_${d}_${i}_${LC}_spring_stats.txt ] 
		then 
			continue
		fi

		SSM=$SM_TOOLS_REPO/$f
		$G r.external band=$i in=$SSM out=SSM --o
		$G r.null setnull=0 map=SSM
		$G g.region rast=SSM 

		for m in $(perl -e 'for $i (6..10) {printf "%02d\n",$i}')
		do
			$G v.to.rast in=${LC}_${m}2017 out=${LC}_${m}2017 use=cat label=crop_en mem=8000 --o
		done
		for m in $(perl -e 'for $i (6..10) {printf "%02d\n",$i}')
		do
			ofs=$(expr 10000 \* $m)
			$G r.mapcalc expr="${LC}_${m}2017_$ofs = ${LC}_${m}2017 + $ofs" --o
		done

		# consolidating multiple LCs, this is site specific :-/ do we need to save them?
		$G r.patch in="${LC}_062017_60000,${LC}_072017_70000,${LC}_082017_80000,${LC}_092017_90000,${LC}_102017_100000" out=${LC}_spring --o

		for season in spring 
		do
			$G r.stats.zonal2 -r base=${LC}_$season cover=SSM rules=$R_CNT method=count out=SSM_count --o
			$G r.stats.zonal2 -r base=${LC}_$season cover=SSM rules=$R_MIN method=min out=SSM_min --o
			$G r.stats.zonal2 -r base=${LC}_$season cover=SSM rules=$R_MAX method=max out=SSM_max --o
			$G r.stats.zonal2 -r base=${LC}_$season cover=SSM rules=$R_AVG method=average out=SSM_mean --o
			$G r.stats.zonal2 -r base=${LC}_$season cover=SSM rules=$R_STD method=stddev2 out=SSM_stddev --o
			$G r.stats.zonal2 -r base=${LC}_$season cover=SSM rules=$R_SKW method=skewness2 out=SSM_skewness --o
			$G r.stats.zonal2 -r base=${LC}_$season cover=SSM rules=$R_KUR method=kurtosis2 out=SSM_kurtosis --o
			echo "map|cat|crop|count|min|max|avg|stddev|skew|kurt" >$OUTDIR/SSM_${d}_${i}_${LC}_${season}_stats.txt
			for l in $($G r.category map=${LC}_$season sep=\||cut -d\| -f1) 
			do
				count=$(egrep "^$l =" $R_CNT|cut -d' ' -f4|cut -d. -f1)
				# skip when number of cells is too low
				if [ $count -ge $MINCELLS ]
				then
					cat=$(getcat $l)
					map=$(getmap $l)
					crop=$($G r.category map=$map cat=$cat sep=\||cut -d\| -f2)
					min=$(egrep "^$l =" $R_MIN|cut -d' ' -f4|sed -e 's/-nan/NA/')
					max=$(egrep "^$l =" $R_MAX|cut -d' ' -f4|sed -e 's/-nan/NA/')
					avg=$(egrep "^$l =" $R_AVG|cut -d' ' -f4|sed -e 's/-nan/NA/')
					stddev=$(egrep "^$l =" $R_STD|cut -d' ' -f4|sed -e 's/-nan/NA/')
					skew=$(egrep "^$l =" $R_SKW|cut -d' ' -f4|sed -e 's/-nan/NA/')
					kurt=$(egrep "^$l =" $R_KUR|cut -d' ' -f4|sed -e 's/-nan/NA/')
					echo "$map|$cat|$crop|$count|$min|$max|$avg|$stddev|$skew|$kurt" >>$OUTDIR/SSM_${d}_${i}_${LC}_${season}_stats.txt
				fi
			done
		done
	done
done

rm -f $R_CNT $R_MIN $R_MAX $R_AVG $R_STD $R_SKW $R_KUR

$G_CLEAN
