#!/bin/sh

# This tiny script is used to import the Apulian Tavoliere land cover and
# split it by month of survey. Note that geometries are partially overlapping
# so a direct import into grass would result in rough errors for broken
# topologies

cd /ocean/processings/processing_sites/site_Italy/shapefile/ITALY_LANDCOVER_2017_pol.REV.20180730

LC=ITALY_LANDCOVER_2017_pol.REV.20180730_33N

ogrinfo -sql 'alter table ITALY_LANDCOVER_2017_pol.REV.20180730_33N add column ISOdate character(10)' ITALY_LANDCOVER_2017_pol.REV.20180730_33N.shp

N=$(ogrinfo -sql "select count(*) from \"$LC\"" $LC.shp|grep =|cut -d= -f2|sed -e 's/ //')
DATES=$(ogrinfo -sql "select distinct Date from \"$LC\"" $LC.shp|grep =|cut -d= -f2)

for i in $DATES
do
	D=$(echo $i|perl -pe 's/ ([1-9])-/ 0$1-/'|sed -e 's/Apr/04/' -e 's/Mar/03/' -e 's/Aug/08/' -e 's/Sep/09/' -e 's/Jun/06/' -e 's/May/05/' -e 's/Oct/10/' -e 's/Jul/07/'|perl -ne 'chomp; ($d,$m,$y)=split(/-/); $d =~ s/ //; print sprintf(qq/%04d-%02d-%02d\n/,$y,$m,$d);')
	ogrinfo  -dialect SQLite -sql "UPDATE \"$LC\" SET ISOdate='$D' where Date='$i'" $LC.shp
done

S=apulian_tavoliere_lc_2017_rev20180730.splite
ogr2ogr -f SQLite -t_srs EPSG:4326 $S $LC.shp
T=$(echo $LC|tr '[A-Z]' '[a-z]')

# multiple vectors for multiple months 
for m in 03 04 05 06 07 08 09 10 
do
	ogr2ogr -f SQLite -dialect SQLite -where "strftime('%m',isodate)='$m' and crop_en<>'NO'" M${m}_$S $S
done

# now importing in grass
for m in 03 04 05 06 07 08 09 10 
do
	$G_PERM v.import snap=-1 in=M${m}_$S out=apuliantavoliere_${m}2017 --o
done

exit 0
