#!/bin/sh
#
# This script associate a land cover to each field in the Spain LPI map, as
# found in the ItaCyl classification. Output is limited to 4ha fields for
# efficiency
#

cd /ocean/projects/EU_SENSAGRI/Test_sites/Spain/Itacyl/border_fields

for s in $(find . -name '*.shp'|grep WGS84|grep -v 1ha)
do
	f=$(basename $s .shp)
	v=RECFE_$(echo $f|cut -d_ -f1)
	$G_PERM v.in.ogr in=$s out=${v}_4ha where='SUPERFICIE>=40000' snap=-1 --o 
done
# Note that one of the input shapefile has a different scheme, so it needs a
# normalization step, i.e. 
#
$G_PERM v.db.addcolumn map=RECFE_05_4ha col='C_REFREC char(23)' 
$G_PERM db.execute sql='ALTER TABLE RECFE_05_4ha RENAME TO _RECFE_05_4ha_old'
$G_PERM db.execute sql="CREATE TABLE RECFE_05_4ha(cat integer PRIMARY KEY,DN_OID double precision, SUPERFICIE double precision, PERIMETRO double precision, PROVINCIA integer, MUNICIPIO integer, AGREGADO integer, ZONA integer, POLIGONO integer, PARCELA integer, RECINTO integer, COEF_REGAD integer, USO_SIGPAC character(2), C_REFREC character(23));"
$G_PERM db.execute sql="insert into table RECFE_05_4ha SELECT * FROM _RECFE_05_4ha_old;"
$G_PERM db.execute sql="insert into RECFE_05_4ha SELECT * from _RECFE_05_4ha_old;"

$G_PERM v.patch in=$($G_PERM g.list t=vect pat='RECFE*4ha' sep=,) out=spain_fields_4ha -e --o
$G_PERM v.to.rast in=spain_fields_4ha out=spain_fields_4ha type=area use=cat mem=4096 --o

$G_PERM r.statistics base=spain_fields_4ha cover=spain_2017 output=spain_fields_4ha_lc method=mode --o
$G_PERM r.statistics base=spain_fields_4ha cover=spain_2017 output=spain_fields_4ha_lc_div method=diversity --o

$G_PERM r.category spain_fields_4ha_lc >$SM_TOOLS_OUTPUTDIR/spain_fields_4ha_landcover_cat.txt
$G_PERM r.category spain_fields_4ha_lc_div >$SM_TOOLS_OUTPUTDIR/spain_fields_4ha_landcover_div.txt

exit 0
