#!/bin/bash

# These masks refer to July 2018, as extracted from NDVI with different thresholds
# They should correspond to different approximations of irrigated fields in raster representation.

set -e

TAG=ndvi_40m_initial_release
YEAR1=2017
YEAR2=2018
OUTDIR=$SM_TOOLS/streams_crossing/results
REGION="POLYGON ((-4.5356 41.7828,-3.754 41.7828,-3.754 41.5092,-4.5356 41.5092,-4.5356 41.7828))"


#Tomato Maize Brocoli Fennel Durum Wheat,Artichoke,Asparagus,Pepper,Spinach

for CROPCODE in trigo:1 maize:4 cebada:5 remolacha:82
do

CROP=$(echo $CROPCODE|cut -d: -f1)
CODE=$(echo $CROPCODE|cut -d: -f2)


SSM1=$(spatialite -batch -noheader $SM_TOOLS_DB<<EOF
select filename,date(reference_datetime) from Product where tag='$TAG' and strftime('%Y',reference_datetime)='$YEAR1' and
ST_Intersects(boundingbox,ST_GeomFromText('$REGION',4326))>0;
EOF
)
SSM2=$(spatialite -batch -noheader $SM_TOOLS_DB<<EOF
select filename,date(reference_datetime) from Product where tag='$TAG' and strftime('%Y',reference_datetime)='$YEAR2' and
ST_Intersects(boundingbox,ST_GeomFromText('$REGION',4326))>0;
EOF
)

echo "code|crop|date|avg|stddev" >$OUTDIR/NDVI_spain_${YEAR1}_${CROP}_stats.txt
echo "code|crop|date|avg|stddev" >$OUTDIR/NDVI_spain_${YEAR2}_${CROP}_stats.txt

$G g.region rast=spain_$YEAR1
$G r.mask ras=spain_$YEAR1 maskcats="$CODE" --o
for l in $SSM1
do
	f=$(echo $l|cut -d\| -f1)
	d=$(echo $l|cut -d\| -f2)
	$G r.external in=$SM_TOOLS_REPO/$f out=$f --o
	$G g.region rast=$f 
	eval $($G r.univar -g map=$f)
	echo "$CODE|$CROP|$d|$mean|$stddev"	>>$OUTDIR/NDVI_spain_${YEAR1}_${CROP}_stats.txt
done

$G g.region rast=spain_$YEAR2
$G r.mask ras=spain_$YEAR2 maskcats="$CODE" --o
for l in $SSM2
do
	f=$(echo $l|cut -d\| -f1)
	d=$(echo $l|cut -d\| -f2)
	$G r.external in=$SM_TOOLS_REPO/$f out=$f --o
	$G g.region rast=$f 
	eval $($G r.univar -g map=$f)
	echo "$CODE|$CROP|$d|$mean|$stddev"	>>$OUTDIR/NDVI_spain_${YEAR2}_${CROP}_stats.txt
done

done

$G r.mask -r

exit 0
