#!/bin/sh
#
# This scripts extracts zonal statistics for NDVI maps in Apulian Tavoliere
# using base land cover maps for the area which is available in different months.
#

set -e

LC=spain
OUTDIR=$SM_TOOLS/streams_crossing/results
MINCELLS=1
CLAY=$SM_TOOLS_TEXTURE/CLYPPT_M_sl1_250m.tif
SAND=$SM_TOOLS_TEXTURE/SNDPPT_M_sl1_250m.tif
YEAR=2017
R_CNT=$(mktemp -q)
RES=$(pkinfo -dx -i $SAND|cut -d' ' -f2)

R_CNT=$(mktemp -q)

$G g.region res=$RES rast=$($G g.list t=rast pat="${LC}_$YEAR")
$G v.mkgrid map=GRID pos=region grid=1,1 --o
$G v.out.ogr out=$SM_TOOLS_TMPDIR/grid.shp in=GRID type=area --o
gdalwarp -overwrite  -wo 'CUTLINE_ALL_TOUCHED=TRUE' -of ENVI -cutline $SM_TOOLS_TMPDIR/grid.shp -crop_to_cutline $SAND $SM_TOOLS_TMPDIR/sand
gdalwarp -overwrite  -wo 'CUTLINE_ALL_TOUCHED=TRUE' -of ENVI -cutline $SM_TOOLS_TMPDIR/grid.shp -crop_to_cutline $CLAY $SM_TOOLS_TMPDIR/clay
$G r.external in=$SM_TOOLS_TMPDIR/sand out=SAND --o
$G r.external in=$SM_TOOLS_TMPDIR/clay out=CLAY --o

# This is a way to trim a looooot of polygons  
$G r.clump in=${LC}_$YEAR out=${LC}_${YEAR}_clump --o
$G r.area in=${LC}_${YEAR}_clump out=${LC}_${YEAR}_clump_1ha lesser=$MINCELLS --o
$G r.clump in=${LC}_${YEAR}_clump_1ha out=${LC}_lc_clump --o
$G r.mapcalc expr="${LC}_lc=${LC}_${YEAR}" --o

# This is a trick to have a map cat -> land cover class
$G r.statistics base=${LC}_lc_clump cover=${LC}_lc method=mode out=LC_cat --o

$G r.soils.texture sand=SAND clay=CLAY out=texture scheme=$SM_TOOLS/etc/USDA.dat --o
$G r.null setnull=0 map=texture
$G r.stats.zonal2 -r base=${LC}_lc_clump cover=texture rules=$R_CNT method=count out=texture_count --o
$G r.statistics base=${LC}_lc_clump cover=texture method=mode out=texture_mode --o
$G r.statistics base=${LC}_lc_clump cover=texture method=diversity out=texture_div --o
echo "cat|count|crop|texture|diversity" >$OUTDIR/SOIL_${LC}_stats.txt
for l in $($G r.category map=LC_cat sep=\|) 
do
	cat=$(echo $l|cut -d\| -f1)
	class=$(echo $l|cut -d\| -f2)
	count=$(egrep "^$cat =" $R_CNT|cut -d' ' -f4|cut -d. -f1)
	# skip when number of cells is too low
	if [ $count -ge $MINCELLS ]
	then
		crop=$($G r.category map=${LC}_lc cat=$class sep=\||cut -d\| -f2)
		mode=$($G r.category map=texture_mode cat=$cat sep=\||cut -d\| -f2)
		div=$($G r.category map=texture_div cat=$cat sep=\||cut -d\| -f2)
		text=$($G r.category map=texture cat=$mode sep=\||cut -d\| -f2)
		echo "$cat|$count|$crop|$text|$div" >>$OUTDIR/SOIL_${LC}_stats.txt
	fi
done

rm -f $R_CNT

$G_CLEAN
