#!/bin/sh
#
# This scripts extracts zonal statistics for SSM maps in Spain
# using base land cover maps for the area which is available as a single date and pre-loaded.
#
#1	TRIGO
#2	CENTENO
#4	MAIZ
#5	CEBADA
#6	AVENA
#7	TRITICALE
#8	OTROS CEREALES
#9	ROQUEDOS
#20	SUELO DESNUDO
#33	GIRASOL
#35	COLZA
#39	OTRAS LEGUMINOSAS GRANO
#40	GUISANTES
#60	ALFALFA
#61	FORRAJERAS
#70	TRIGO REGADIO
#71	CEBADA REGADIO
#72	ALFALFA REGADIO
#73	GIRASOL REGADIO
#75	CENTENO REGADIO
#76	AVENA REGADIO
#77	TRITICALE REGADIO
#80	OTROS CULTIVOS INDUSTRIALES
#82	REMOLACHA
#94	PATATAS
#100	VINEDO
#101	OLIVAR
#110	HORTICOLA
#177	AROMATICAS
#181	FRUTALES
#183	FRUTALES CASCARA

set -e

TAG=p_ssm40m_sensagri_img_th33_mean_run_n4_v1_2_20190315_dsc
LC=spain
OUTDIR=$SM_TOOLS/streams_crossing/results
YEAR=2017
SSM_BANDS=1

# The SSM maps are 40x40m^2 wide.
#MINCELLS=7
MINCELLS=28

ROWS=$(spatialite -batch -noheader $SM_TOOLS_DB <<EOF
select p.filename,date(p.reference_datetime) from Product as p, Site as s 
where p.tag='$TAG' and strftime('%Y',p.reference_datetime)='$YEAR' 
and s.id=5 and ST_Intersects(p.footprint,s.aoi)>0;
EOF
)

R_CAT=$(mktemp -q)
R_CNT=$(mktemp -q)
R_MIN=$(mktemp -q)
R_MAX=$(mktemp -q)
R_AVG=$(mktemp -q)
R_STD=$(mktemp -q)
R_SKW=$(mktemp -q)
R_KUR=$(mktemp -q)

# select only some classes
$G r.reclass in=${LC}_$YEAR rules=- out=${LC}_${YEAR}_reclass --o <<EOF
1 = 1 TRIGO
4 = 4 MAIZ
70 = 70	TRIGO REGADIO
EOF

for r in $ROWS
do
	f=$(echo $r|cut -d\| -f1)
	d=$(echo $r|cut -d\| -f2)
	for i in $SSM_BANDS
	do
		echo "SSM $d $i" 
        if [ -f $OUTDIR/SSM_${d}_${i}_${LC}_stats.txt ]
        then
            continue
        fi

		SSM=$SM_TOOLS_REPO/$f
		$G r.in.gdal band=$i in=$SSM out=SSM --o
		$G r.null setnull=0 map=SSM
		$G g.region rast=SSM 

		# This is a way to trim a looooot of polygons  
		$G r.clump in=${LC}_${YEAR}_reclass out=${LC}_${YEAR}_clump --o
		$G r.area in=${LC}_${YEAR}_clump out=${LC}_${YEAR}_clump_1ha lesser=$MINCELLS --o
		$G r.clump in=${LC}_${YEAR}_clump_1ha out=${LC}_lc_clump --o
		$G r.mapcalc expr="${LC}_lc=${LC}_${YEAR}" --o

		# This is a trick to have a map cat -> land cover class
		#$G r.statistics base=${LC}_lc_clump cover=${LC}_lc method=mode out=SSM_cat --o

		$G r.stats.zonal2 -r base=${LC}_lc_clump cover=${LC}_lc rules=$R_CAT method=min out=SSM_cat --o
		$G r.stats.zonal2 -r base=${LC}_lc_clump cover=SSM rules=$R_CNT method=count out=SSM_count --o
		$G r.stats.zonal2 -r base=${LC}_lc_clump cover=SSM rules=$R_MIN method=min out=SSM_min --o
		$G r.stats.zonal2 -r base=${LC}_lc_clump cover=SSM rules=$R_MAX method=max out=SSM_max --o
		$G r.stats.zonal2 -r base=${LC}_lc_clump cover=SSM rules=$R_AVG method=average out=SSM_mean --o
		$G r.stats.zonal2 -r base=${LC}_lc_clump cover=SSM rules=$R_STD method=stddev2 out=SSM_stddev --o
		$G r.stats.zonal2 -r base=${LC}_lc_clump cover=SSM rules=$R_SKW method=skewness2 out=SSM_skewness --o
		$G r.stats.zonal2 -r base=${LC}_lc_clump cover=SSM rules=$R_KUR method=kurtosis2 out=SSM_kurtosis --o
		echo "map|cat|crop|count|min|max|avg|stddev|skew|kurt" >$OUTDIR/SSM_${d}_${i}_${LC}_stats.txt
		for cat in $(cut -d= -f1 $R_CAT) 
		do
			class=$(egrep "^$cat =" $R_CAT|cut -d' ' -f4|cut -d. -f1)
			count=$(egrep "^$cat =" $R_CNT|cut -d' ' -f4|cut -d. -f1)
			# skip when number of cells is too low
			if [ $count -ge $MINCELLS ]
			then
				crop=$($G r.category --v map=${LC}_lc cat=$class sep=\||cut -d\| -f2)
				min=$(egrep "^$cat =" $R_MIN|cut -d' ' -f4|sed -e 's/-nan/NA/')
				max=$(egrep "^$cat =" $R_MAX|cut -d' ' -f4|sed -e 's/-nan/NA/')
				avg=$(egrep "^$cat =" $R_AVG|cut -d' ' -f4|sed -e 's/-nan/NA/')
				stddev=$(egrep "^$cat =" $R_STD|cut -d' ' -f4|sed -e 's/-nan/NA/')
				skew=$(egrep "^$cat =" $R_SKW|cut -d' ' -f4|sed -e 's/-nan/NA/')
				kurt=$(egrep "^$cat =" $R_KUR|cut -d' ' -f4|sed -e 's/-nan/NA/')
				echo "$cat|$class|$crop|$count|$min|$max|$avg|$stddev|$skew|$kurt" >>$OUTDIR/SSM_${d}_${i}_${LC}_stats.txt
			fi
		done
	done
done

rm -f $R_CAT $R_CNT $R_MIN $R_MAX $R_AVG $R_STD $R_SKW $R_KUR

$G_CLEAN

