#
# This script loads results of processings of LAI, SSM, NDVI, TLG and TEXT
# data and prepare all dataframe 
#

# strips outlier from an array of input data
remove_outliers <- function(x, na.rm = TRUE, ...) {
  qnt <- quantile(x, probs=c(.25, .75), na.rm = na.rm, ...)
  H <- 1.5 * IQR(x, na.rm = na.rm)
  y <- x
  y[x < (qnt[1] - H)] <- NA
  y[x > (qnt[2] + H)] <- NA
  y
}

# Strips outlier from a boxplot result
bp_strip_outliers <- function(df) {
	df_stripped <- df
	bp <- boxplot(df$avg ~ df$date, plot=F)
	for (i in 1:length(bp$out)) {
		g <- bp$names[i]
		o <- bp$out[i]
		df_stripped <- subset(df_stripped, date!=g | avg!=o)
	}
	df_stripped
}

read_csv <- function(x) { read.csv(x, sep="|", header=T)}

home = Sys.getenv('HOME')
setwd(file.path(home,'sm-tools', 'streams_crossing', 'results'))

#lai_files <- Sys.glob("LAI*spain*.txt")
lai_files <- Sys.glob("LAI*spain_fields_4ha_lc_stats.txt")
lai_dates <- strsplit(lai_files, split="_")
lai <- lapply(lai_files, read_csv)
for (i in 1:length(lai_dates)) { lai[[i]]$date <- lai_dates[[i]][2]; }

ndvi_files <- Sys.glob("NDVI*spain*.txt")
ndvi_dates <- strsplit(ndvi_files, split="_")
ndvi <- lapply(ndvi_files, read_csv)
for (i in 1:length(ndvi_dates)) { ndvi[[i]]$date <- ndvi_dates[[i]][2]; }

#ssm_files <- Sys.glob("SSM*spain*.txt")
ssm_files <- Sys.glob("SSM*spain_fields_4ha_lc_stats.txt")
#ssm_files <- Sys.glob("SSM*spain_laiarea_fields_4ha*.txt")
ssm_dates <- strsplit(ssm_files, split="_")
ssm <- lapply(ssm_files, read_csv)

for (i in 1:length(ssm_dates)) { ssm[[i]]$date <- ssm_dates[[i]][2]; }

tlg_files <- Sys.glob("TLG*spain*.txt")
tlg_dates <- strsplit(tlg_files, split="_")
tlg <- lapply(tlg_files, read_csv)
for (i in 1:length(tlg_dates)) { tlg[[i]]$date <- tlg_dates[[i]][2]; }

soil_files <- Sys.glob("SOIL*spain*.txt")
soil_dates <- strsplit(soil_files, split="_")
soil <- lapply(soil_files, read_csv)
for (i in 1:length(soil_dates)) { soil[[i]]$date <- soil_dates[[i]][2]; }

par(mar=c(9,3,2,2)) # set borders: bottom, left, top, right

# merge series of data

lai_all <- lai[[1]]
for (i in 2:length(lai)) { lai_all <- rbind(lai_all, lai[[i]]) }
ssm_all <- ssm[[1]]
for (i in 2:length(ssm)) { ssm_all <- rbind(ssm_all, ssm[[i]]) }
ndvi_all <- ndvi[[1]]
for (i in 2:length(ndvi)) { ndvi_all <- rbind(ndvi_all, ndvi[[i]]) }
tlg_all <- tlg[[1]]
for (i in 2:length(tlg)) { tlg_all <- rbind(tlg_all, tlg[[i]]) }


# Example merges by columns to subset() on multiple data at the same

colnames(ssm_all)[colnames(ssm_all)=="cat"] <- "class"
colnames(ssm_all)[colnames(ssm_all)=="map"] <- "cat"

selection<-unique(lai_all$cat)
ssm_laifields <- subset(ssm_all, cat %in% selection)

#lai2ssm <- merge(lai_all, ssm_all, by=c("cat","date"), suffixes=c(".lai",".ssm"));

#ssm2tlg <- merge(ssm_all, tlg_all, by=c("cat","date"), suffixes=c(".ssm",".tlg"), all.x=T );
#filt <- subset(ssm2tlg, is.na(tillage))

#lai2ndvi <- merge(lai_all, ndvi_all, by=c("cat","date"), suffixes=c(".lai",".ndvi"));

# SOME USEFUL HINTS:
#
#
# *** Set 2x1 graphics grid
# par(mfrow=c(2,1)) 
#
# plot(df$crop, df$avg, las=2, main="SSM/LAI/NDVI mean" )
# plot(df$crop, df$stddev, las=2, main="SSM/LAI/NDVI Std Dev" )
#
# sb <- subset(df, crop=="Durum Wheat" & abs(skew)<=0.5 & abs(kurt)<=0.5)
# distinct(select(df,'map','cat'))

# *** Boxplots 
# bp <- boxplot(ssm_all$avg ~ ssm_all$date, ylim=c(500,3000), las=2)
#

#
# summary(df)
#


# *** This is to add average as single points on boxplots.
# means <- tapply(df$avg,df$date,mean)
# points(means,col="red",pch=18)
