#!/bin/sh
#
# This scripts extracts zonal statistics for NDVI maps in Apulian Tavoliere
# using base land cover maps for the area which is available in different months.
#

set -e

LC=spain
TAG=tillage_40m_initial_release
OUTDIR=$SM_TOOLS/streams_crossing/results
MINCELLS=28
YEAR=2017
R_CNT=$(mktemp -q)

ROWS=$(spatialite -batch -noheader $SM_TOOLS_DB <<EOF
select p.filename,date(p.reference_datetime) from Product as p, Site as s 
where p.tag='$TAG' and strftime('%Y',p.reference_datetime)='$YEAR' 
and s.id=5 and ST_Intersects(p.footprint,s.aoi)>0;
EOF
)

# select only some classes
$G r.reclass in=${LC}_$YEAR rules=- out=${LC}_${YEAR}_reclass --o <<EOF
1 = 1 TRIGO
4 = 4 MAIZ
70 = 70	TRIGO REGADIO
EOF

for r in $ROWS
do
	f=$(echo $r|cut -d\| -f1)
	d=$(echo $r|cut -d\| -f2)
	echo "TLG $d" 
	if [ -f $OUTDIR/TLG_${d}_${LC}_winter_stats.txt ] 
	then 
		continue
	fi

	TLG=$SM_TOOLS_REPO/$f
	$G r.in.gdal -e in=$TLG out=TLG --o
	$G g.region rast=TLG 
	$G r.null -c map=TLG --o
	$G r.null setnull=255,128,129 map=TLG
	$G r.category map=TLG sep=: rules=- <<EOF
1:Harrowed
2:Ploughed
EOF

	# This is a way to trim a looooot of polygons  
	$G r.clump in=${LC}_$YEAR out=${LC}_${YEAR}_clump --o
	$G r.area in=${LC}_${YEAR}_clump out=${LC}_${YEAR}_clump_1ha lesser=$MINCELLS --o
	$G r.mapcalc expr="${LC}_lc_clump=${LC}_${YEAR}_clump_1ha" --o
	$G r.mapcalc expr="${LC}_lc=${LC}_${YEAR}" --o

	# This is a trick to have a map cat -> land cover class
	$G r.statistics base=${LC}_lc_clump cover=${LC}_lc method=mode out=TLG_cat --o


	$G r.stats.zonal2 -r base=${LC}_lc_clump cover=TLG rules=$R_CNT method=count out=tlg_count --o
	$G r.statistics base=${LC}_lc_clump cover=TLG method=mode out=tlg_mode --o
	$G r.statistics base=${LC}_lc_clump cover=TLG method=diversity out=tlg_div --o
	echo "cat|class|count|crop|tillage|diversity" >$OUTDIR/TLG_${d}_${LC}_stats.txt
	for l in $($G r.category map=TLG_cat sep=\|) 
	do
		cat=$(echo $l|cut -d\| -f1)
		class=$(echo $l|cut -d\| -f2)
		count=$(egrep "^$cat =" $R_CNT|cut -d' ' -f4|cut -d. -f1)
		# skip when number of cells is too low
		if [ $count -ge $MINCELLS ]
		then
			crop=$($G r.category map=${LC}_lc cat=$class sep=\||cut -d\| -f2)
			mode=$($G r.category map=tlg_mode cat=$cat sep=\||cut -d\| -f2)
			div=$($G r.category map=tlg_div cat=$cat sep=\||cut -d\| -f2)
			tlg=$($G r.category map=TLG cat=$mode sep=\||cut -d\| -f2)
			echo "$cat|$class|$count|$crop|$tlg|$div" >>$OUTDIR/TLG_${d}_${LC}_stats.txt
		fi
	done
done

rm -f $R_CNT

$G_CLEAN
