
# Useful tools for SMOSar application and other beasts.

These scripts are neither general nor robust enough for any general use, 
just used in the processing toolchain to automatically deal with stacks of
Sentinel-1, Sentinel-2, ground data and resulting maps related to SMOSAR[1]
algorithm and its successive evolutions. 

However, most of the stuff could be relevant in other contexts 
with appropriate changes. This is a multi-tools/multi-languages software kit,
in the pure approach of \*nix zen of programming: i.e. use the proper tool
for the proper task, do not reinvent the wheel.

Most of the scripts work on a giant Spatialite database to maintain metadata 
information and allow an automagically extraction of data and statistics with 
suitable geospatial queries, to simplify management of many different sites.

The most stable part is developed in Perl, but a lot of scripts are
written in Bourne Shell or Bash, with intensive use of GDAL tools,
PKTools and finally GRASS GIS whenever required. Ideally those parts - when
general enough for common use - should/will be translated into Perl, with a
decent level of abstraction and generality. But this is a slow process
and often things change in course or need to be done differently.
Therefore some scripts could never see the light of the day...

Some scripts are also rough enough to be too be just a proof of concept
and not robust enough even against simple changes in input data.

Current tools work with SMOSAR maps, SMAP and SMOS images, field data, 
Some formats are neither documented nor standardized. They are also
consequence of the cooperation with a proprietary world (e.g. Gamma gmbh, 
ENVI)

# List of the required Perl modules:

Archive::Zip;  
Carp;  
Data::Dumper;  
Data::GUID;  
File::Basename;  
File::Path;  
File::Spec;  
File::stat;  
FindBin;  
Fortran::Format;  
Geo::GDAL;  
Geo::GDAL::Const;  
Getopt::Long;  
Pod::Usage;  
Spreadsheet::ParseExcel;  
Text::CSV;  
Config::IniFiles;  
Data::Dumper;  
Data::Find;  
Data::Validate::URI;  
DateTime;  
DateTime::Format::DateParse;  
DBI;  
File::Spec;  
JSON;  
LWP::UserAgent;  
URI::Escape;  
XML::Simple;  

# List of required tools:

Grass GIS 7.2+  
Perl  
Awk, sed, grep and their brothers  
R 3.4  
Gdal library and tools  
Spatialite  
Bash  
PKTools  

# Grass GIS pattern of use

One of the main aspects of SM-Tools is the use of GRASS tools in a
transparent manner, even for people that have no training on it. Therefore the 
automagically use of temporary locations is intensive. In some cases working
layers are stored in persistent locations and mapsets: this is generally 
preferred, when those layers are used in multiple scripts and regenerating
them on fly is inefficient or even complicated enough to suggest taking
them apart.

Ideally all those data should be generated all together in setup phase.
SM-Tools is still along the road on those regards, unfortunately.

# Full installation and setup

This is the weakest part of this software kit, due to its multilanguage/multitools 
nature. In fact, there is not a single installation script that is able to
install all dependencies, but for a draft Debian package. A possibile approach
for this problem would be providing a docker image, but it is still not
available, so the user is still on her/his own for installing all required
tools and packages/libraries. Note that the whole set of scripts is conceived 
to be run by each user from a subdir in her/his home. 

# Reference

[1] Balenzano A., Satalino G., Lovergine F., Rinaldi M., Iacobellis V., Mastronardi N., Mattia F., 
	"On the use of temporal series of L- and X-band SAR data for soil moisture retrieval. Capitanata 
	plain case study," European Journal of Remote Sensing, vol. 46, no. 1, pp. 721-737, December 2013.
